@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAutomaticTopologyMeshSource.h,v $
   Language:  C++
-  Date:      $Date: 2007-12-21 15:25:33 $
-  Version:   $Revision: 1.16 $
+  Date:      $Date: 2008-05-26 02:38:23 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -127,12 +127,12 @@ public:
   typedef typename CellType::CellAutoPointer CellAutoPointer;
 
   /** Different kinds of cells. */
-  typedef VertexCell< CellType >             VertexCell;
-  typedef LineCell< CellType >               LineCell;
-  typedef TriangleCell< CellType >           TriangleCell;
-  typedef QuadrilateralCell< CellType >      QuadrilateralCell;
-  typedef TetrahedronCell< CellType >        TetrahedronCell;
-  typedef HexahedronCell< CellType >         HexahedronCell;
+  typedef ::itk::VertexCell< CellType >        VertexCell;
+  typedef ::itk::LineCell< CellType >          LineCell;
+  typedef ::itk::TriangleCell< CellType >      TriangleCell;
+  typedef ::itk::QuadrilateralCell< CellType > QuadrilateralCell;
+  typedef ::itk::TetrahedronCell< CellType >   TetrahedronCell;
+  typedef ::itk::HexahedronCell< CellType >    HexahedronCell;
 
   /** This class requires that the mesh being built use unsigned long
    * as the identifier type for all its elements. */
