@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCoreAtomImageToUnaryCorrespondenceMatrixProcess.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:28:29 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-05-12 17:26:20 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -40,7 +40,7 @@ namespace itk
  * \ingroup 
  */
 template< typename TSourceImage >
-class CoreAtomImageToUnaryCorrespondenceMatrixProcess : public ProcessObject
+class ITK_EXPORT CoreAtomImageToUnaryCorrespondenceMatrixProcess : public ProcessObject
 {
 public:
   /** Number of dimensions. */
@@ -48,9 +48,9 @@ public:
 
   /** Standard class typedefs. */
   typedef CoreAtomImageToUnaryCorrespondenceMatrixProcess  Self;
-  typedef ProcessObject Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef ProcessObject                                    Superclass;
+  typedef SmartPointer<Self>                               Pointer;
+  typedef SmartPointer<const Self>                         ConstPointer;
 
   /** Smart Pointer type to a DataObject. */
   typedef DataObject::Pointer DataObjectPointer;
@@ -62,26 +62,28 @@ public:
   itkTypeMacro(CoreAtomImageToUnaryCorrespondenceMatrixProcess, ProcessObject);
 
   /** GetMacros for number of rows and columns in the unary correspondence matrix. */
-  itkGetMacro(Rows, int);
-  itkGetMacro(Columns, int);
+  itkGetConstMacro(Rows, int);
+  itkGetConstMacro(Columns, int);
 
   /** Typedef for core atom image. */
-  typedef TSourceImage CoreAtomImageType;
-  typedef typename CoreAtomImageType::Pointer CoreAtomImagePointer;
-  typedef typename CoreAtomImageType::RegionType CoreAtomImageRegionType; 
-  typedef typename CoreAtomImageType::PixelType CoreAtomImagePixelType; 
+  typedef TSourceImage                             CoreAtomImageType;
+  typedef typename CoreAtomImageType::Pointer      CoreAtomImagePointer;
+  typedef typename CoreAtomImageType::RegionType   CoreAtomImageRegionType; 
+  typedef typename CoreAtomImageType::PixelType    CoreAtomImagePixelType; 
   typedef typename CoreAtomImageType::ConstPointer CoreAtomImageConstPointer;
 
   /** Typedef for correspondence matrix. */
-  typedef MatrixResizeableDataObject<double> CorrespondenceMatrixType;
+  typedef MatrixResizeableDataObject<double>         CorrespondenceMatrixType;
   typedef typename CorrespondenceMatrixType::Pointer CorrespondenceMatrixPointer;
 
   /** MedialNode typedef. */
   typedef BloxCoreAtomPixel<itkGetStaticConstMacro(NDimensions)> MedialNodeType;
 
   /** UnaryMetric typedef. */
-  typedef UnaryMedialNodeMetric<itkGetStaticConstMacro(NDimensions)> UnaryMetricType;
-  typedef typename UnaryMedialNodeMetric<itkGetStaticConstMacro(NDimensions)>::Pointer UnaryMetricPointer;
+  typedef UnaryMedialNodeMetric<itkGetStaticConstMacro(NDimensions)>
+                                           UnaryMetricType;
+  typedef typename UnaryMedialNodeMetric<itkGetStaticConstMacro(NDimensions)>::Pointer
+                                           UnaryMetricPointer;
 
   /** Get the image output of this process object. */
   CorrespondenceMatrixType * GetOutput(void);
@@ -122,8 +124,7 @@ private:
   int m_Columns;
 
   CorrespondenceMatrixPointer m_CorrespondenceMatrix;
-
-  UnaryMetricPointer m_Metric;
+  UnaryMetricPointer          m_Metric;
 
   /** Flag to output test png files. Off by default. */
   bool m_OutputPNG;
