@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDeformableMesh3DFilter.h,v $
   Language:  C++
-  Date:      $Date: 2004-08-07 17:20:40 $
-  Version:   $Revision: 1.26 $
+  Date:      $Date: 2009-04-28 17:42:50 $
+  Version:   $Revision: 1.29 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -38,6 +38,11 @@ namespace itk
  * The potential force is derived from the gradient information in the 
  * medical image and it will make the model deform to fit to the boundary
  * features.
+ *
+ * Computations are handled with points assumed to lie in index space,
+ * not physical space. Reverting to physical space compromises backward
+ * compatibility.
+ *
  * Inputs are:
  *  (1) A deformable triangular model (Mesh). Import using the SetInput method.
  *  (2) A gradient map that make the model deform to fit to the estimated boundary.
@@ -58,7 +63,7 @@ public:
   typedef MeshToMeshFilter<TInputMesh, TOutputMesh> Superclass;
 
   /** Smart pointer typedef support */
-  typedef SmartPointer<Self>  Pointer;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Method of creation through the object factory. */
@@ -68,32 +73,33 @@ public:
   itkTypeMacro(DeformableMesh3DFilter,MeshToMeshFilter);
 
   /** Some typedefs. */
-  typedef TInputMesh InputMeshType;
-  typedef TOutputMesh OutputMeshType;
+  typedef TInputMesh                          InputMeshType;
   typedef typename InputMeshType::PointsContainerPointer
-  InputPointsContainerPointer;
+                                              InputPointsContainerPointer;
   typedef typename InputMeshType::PointsContainer::Iterator
-  InputPointsContainerIterator;
+                                              InputPointsContainerIterator;
   typedef typename InputMeshType::PointDataContainerPointer
-  InputPointDataContainerPointer;
+                                              InputPointDataContainerPointer;
   typedef typename InputMeshType::PointDataContainer::Iterator
-  InputPointDataContainerIterator;
+                                              InputPointDataContainerIterator;
   typedef typename InputMeshType::CellsContainerPointer
-  InputCellsContainerPointer;
+                                              InputCellsContainerPointer;
   typedef typename InputMeshType::CellsContainer::Iterator
-  InputCellsContainerIterator;
+                                              InputCellsContainerIterator;
   typedef typename InputMeshType::CellDataContainerPointer
-  InputCellDataContainerPointer;
+                                              InputCellDataContainerPointer;
   typedef typename InputMeshType::CellDataContainer::Iterator
-  InputCellDataContainerIterator;
+                                              InputCellDataContainerIterator;
+
+  typedef TOutputMesh                         OutputMeshType;
   typedef typename OutputMeshType::PointsContainerPointer
-  OutputPointsContainerPointer;
+                                              OutputPointsContainerPointer;
   typedef typename OutputMeshType::CellsContainer
-  OutputCellsContainer;
+                                              OutputCellsContainer;
   typedef typename OutputMeshType::CellsContainerPointer
-  OutputCellsContainerPointer;
+                                              OutputCellsContainerPointer;
   typedef typename OutputMeshType::PointsContainer::Iterator
-  OutputPointsContainerIterator;
+                                              OutputPointsContainerIterator;
 
   /** Other definitions. */
   typedef typename InputMeshType::CellType          CellType;
@@ -110,8 +116,8 @@ public:
   typedef typename GradientImageType::SizeType         ImageSizeType;
   typedef typename GradientImageType::IndexType        ImageIndexType;
 
-  typedef itk::CellInterface<PixelType, CellTraits>     TCellInterface;
-  typedef itk::TriangleCell<TCellInterface>          TriCell;
+  typedef itk::CellInterface<PixelType, CellTraits>    TCellInterface;
+  typedef itk::TriangleCell<TCellInterface>            TriCell;
 
   typedef CovariantVector<int, 3>                      int3DVector;
   typedef CovariantVector<double, 2>                   double2DVector;
@@ -124,23 +130,23 @@ public:
 
   /* Stiffness Matrix Type definition */
   typedef vnl_matrix_fixed<double, 4, 4>  StiffnessMatrixType;
-  typedef StiffnessMatrixType * StiffnessMatrixRawPointer; 
+  typedef StiffnessMatrixType *           StiffnessMatrixRawPointer; 
 
   /** Routines. */
   void SetStiffnessMatrix( StiffnessMatrixType *stiff, int i );
 
   /** Set/Get routines. */
   itkSetMacro(Gradient, GradientImagePointer);
-  itkGetMacro(Gradient, GradientImagePointer);
+  itkGetConstMacro(Gradient, GradientImagePointer);
 
   itkSetMacro(StepThreshold, int);
-  itkGetMacro(StepThreshold, int);
+  itkGetConstMacro(StepThreshold, int);
 
   itkSetMacro(Stiffness, double2DVector);
-  itkGetMacro(Stiffness, double2DVector);
+  itkGetConstMacro(Stiffness, double2DVector);
 
   itkSetMacro(TimeStep, double);
-  itkGetMacro(TimeStep, double);
+  itkGetConstMacro(TimeStep, double);
 
   itkSetMacro(Scale, double3DVector);
 
@@ -149,7 +155,7 @@ public:
   itkSetMacro(PotentialOn, unsigned short);
   itkSetMacro(ObjectLabel, unsigned char);
 
-  itkGetMacro(Normals, InputMeshPointer);
+  itkGetConstMacro(Normals, InputMeshPointer);
 
 protected:
   DeformableMesh3DFilter();
@@ -186,6 +192,7 @@ private:
   double2DVector    m_Stiffness;
   double            m_TimeStep;      /** Time step of each iteration */
   double3DVector    m_Scale;
+
   int       m_Step;          /** Number of iterations */
   int       m_NumberOfNodes;
   int       m_NumberOfCells;
@@ -193,6 +200,7 @@ private:
   int       m_ImageHeight;
   int       m_ImageDepth;
   int       m_StepThreshold;/** This threshold decides when to stop the model. */
+
   unsigned short m_ModelXUpLimit;
   unsigned short m_ModelXDownLimit;
   unsigned short m_ModelYUpLimit;
@@ -205,7 +213,7 @@ private:
   PixelType      m_PotentialMagnitude;
 
   /** To compute force derived from gradient data. */
-  GradientImagePointer  m_Gradient; 
+  GradientImagePointer        m_Gradient; 
   PotentialImageType::Pointer m_Potential;  
 };
 
