@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkDemonsRegistrationFilter.h,v $
   Language:  C++
-  Date:      $Date: 2004-06-17 15:25:58 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2009-04-23 03:53:35 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef _itkDemonsRegistrationFilter_h_
-#define _itkDemonsRegistrationFilter_h_
+#ifndef __itkDemonsRegistrationFilter_h
+#define __itkDemonsRegistrationFilter_h
 
 #include "itkPDEDeformableRegistrationFilter.h"
 #include "itkDemonsRegistrationFunction.h"
@@ -64,11 +64,11 @@ class ITK_EXPORT DemonsRegistrationFilter :
 {
 public:
   /** Standard class typedefs. */
-  typedef DemonsRegistrationFilter    Self;
+  typedef DemonsRegistrationFilter                  Self;
   typedef PDEDeformableRegistrationFilter<
     TFixedImage, TMovingImage,TDeformationField>    Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef SmartPointer<Self>                        Pointer;
+  typedef SmartPointer<const Self>                  ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -81,11 +81,11 @@ public:
   typedef typename Superclass::TimeStepType  TimeStepType;
 
   /** FixedImage image type. */
-  typedef typename Superclass::FixedImageType   FixedImageType;
+  typedef typename Superclass::FixedImageType     FixedImageType;
   typedef typename Superclass::FixedImagePointer  FixedImagePointer;
 
   /** MovingImage image type. */
-  typedef typename Superclass::MovingImageType    MovingImageType;
+  typedef typename Superclass::MovingImageType     MovingImageType;
   typedef typename Superclass::MovingImagePointer  MovingImagePointer;
   
   /** Deformation field type. */
@@ -112,7 +112,7 @@ public:
   /** Switch between using the fixed image and moving image gradient
    * for computing the deformation field updates. */
   itkSetMacro( UseMovingImageGradient, bool );
-  itkGetMacro( UseMovingImageGradient, bool );
+  itkGetConstMacro( UseMovingImageGradient, bool );
   itkBooleanMacro( UseMovingImageGradient );
 
   /** Set/Get the threshold below which the absolute difference of
