@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageGaussianModelEstimator.h,v $
   Language:  C++
-  Date:      $Date: 2005-03-30 15:13:39 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-04-23 03:53:35 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef _itkImageGaussianModelEstimator_h
-#define _itkImageGaussianModelEstimator_h
+#ifndef __itkImageGaussianModelEstimator_h
+#define __itkImageGaussianModelEstimator_h
 
 #include <math.h>
 #include <float.h>
@@ -83,11 +83,10 @@ class ITK_EXPORT ImageGaussianModelEstimator:
 {
 public:
   /** Standard class typedefs. */
-  typedef ImageGaussianModelEstimator   Self;
+  typedef ImageGaussianModelEstimator                              Self;
   typedef ImageModelEstimatorBase<TInputImage,TMembershipFunction> Superclass;
-
-  typedef SmartPointer<Self>  Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                                       Pointer;
+  typedef SmartPointer<const Self>                                 ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
@@ -102,29 +101,25 @@ public:
   typedef typename TTrainingImage::Pointer TrainingImagePointer;
     
   /** Type definition for the vector associated with
-   * input image pixel type. */     
-  typedef typename TInputImage::PixelType InputImagePixelType;        
+   * input image pixel type. */
+  typedef typename TInputImage::PixelType InputImagePixelType;
 
   /** Type definitions for the vector holding
    * training image pixel type. */
   typedef typename TTrainingImage::PixelType TrainingImagePixelType;
 
   /** Type definitions for the iterators for the input and training images. */
-  typedef
-  ImageRegionIterator< TInputImage >  InputImageIterator;
-  typedef
-  ImageRegionIterator< TTrainingImage > TrainingImageIterator;
+  typedef ImageRegionIterator< TInputImage >    InputImageIterator;
+  typedef ImageRegionIterator< TTrainingImage > TrainingImageIterator;
 
   /** Type definitions for the membership function . */
-  typedef typename TMembershipFunction::Pointer MembershipFunctionPointer ;
+  typedef typename TMembershipFunction::Pointer MembershipFunctionPointer;
 
   /** Set the training image. */
   itkSetMacro(TrainingImage,TrainingImagePointer);
 
   /** Get the training image. */
-  itkGetMacro(TrainingImage,TrainingImagePointer);
-
-
+  itkGetConstMacro(TrainingImage,TrainingImagePointer);
 
 protected: 
   ImageGaussianModelEstimator();
@@ -132,7 +127,7 @@ protected:
   virtual void PrintSelf(std::ostream& os, Indent indent) const;
 
   /** Starts the image modelling process */
-  void GenerateData() ;
+  void GenerateData();
 
 private:
   ImageGaussianModelEstimator(const Self&); //purposely not implemented
@@ -150,7 +145,7 @@ private:
 
   MatrixType            m_NumberOfSamples;
   MatrixType            m_Means;
-  MatrixType            *m_Covariance;  
+  MatrixType           *m_Covariance;  
 
   TrainingImagePointer  m_TrainingImage;
 
@@ -169,6 +164,4 @@ private:
 #include "itkImageGaussianModelEstimator.txx"
 #endif
 
-
-
 #endif
