@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNormalizedMutualInformationHistogramImageToImageMetric.h,v $
   Language:  C++
-  Date:      $Date: 2004-07-13 18:56:40 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-05-02 05:43:55 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -21,42 +21,35 @@
 
 namespace itk
 {
-  /** \class NormalizedMutualInformationHistogramImageToImageMetric
-      \brief Computes normalized mutual information between two images to
-      be registered using the histograms of the intensities in the images.
-
-      The type of Normalize Mutual Information implemented in this class
-      is given by the equation
-
-      \f[  \frac{ H(A) + H(B) }{ H(A,B) }  \f]
-
-      Where \$ H(A) \$ is the entropy of image \$ A \$, 
-            \$ H(B) \$ is the entropy of image \$ B \$,  and
-            \$ H(A,B) \$ is the joing entropy of images \$ A \$ and \$ B \$.  
-
-      Details of this implementation can be found in the book 
-
-      "Medical Image Registration" by Hajnal, Hill and Hawkes. 
-
-      The book is available online at
-
-               http://www-ipg.umds.ac.uk/d.hill/hhh/ 
-
-      The implementation of this class corresponds to equation (30) in
-      Chapter 3 of this book. Note that by slightly changing this class
-      it will be trivial to compute the Normalized Mutual Information
-      measures defined in equations (28) and (29) of the same book.
-
-
-      This class is templated over the type of the fixed and moving
-      images to be compared.
-
-      \ingroup RegistrationMetrics */
+/** \class NormalizedMutualInformationHistogramImageToImageMetric
+ * \brief Computes normalized mutual information between two images to
+ * be registered using the histograms of the intensities in the images.
+ *
+ * The type of Normalize Mutual Information implemented in this class
+ * is given by the equation
+ *
+ *    \f[  \frac{ H(A) + H(B) }{ H(A,B) }  \f]
+ *    Where \$ H(A) \$ is the entropy of image \$ A \$, 
+ *           \$ H(B) \$ is the entropy of image \$ B \$,  and
+ *           \$ H(A,B) \$ is the joing entropy of images \$ A \$ and \$ B \$.  
+ *
+ *    Details of this implementation can be found in the book 
+ *      "Medical Image Registration" by Hajnal, Hill and Hawkes. 
+ *      The book is available online at
+ *               http://www-ipg.umds.ac.uk/d.hill/hhh/ 
+ *    The implementation of this class corresponds to equation (30) in
+ *    Chapter 3 of this book. Note that by slightly changing this class
+ *    it will be trivial to compute the Normalized Mutual Information
+ *    measures defined in equations (28) and (29) of the same book.
+ *
+ *    This class is templated over the type of the fixed and moving
+ *    images to be compared.
+ * \ingroup RegistrationMetrics */
 template <class TFixedImage, class TMovingImage>
 class ITK_EXPORT NormalizedMutualInformationHistogramImageToImageMetric :
 public HistogramImageToImageMetric<TFixedImage, TMovingImage>
 {
- public:
+public:
   /** Standard class typedefs. */
   typedef NormalizedMutualInformationHistogramImageToImageMetric Self;
   typedef HistogramImageToImageMetric<TFixedImage, TMovingImage> Superclass;
@@ -88,7 +81,11 @@ public HistogramImageToImageMetric<TFixedImage, TMovingImage>
     MovingImageConstPointer;
 
   typedef typename Superclass::HistogramType            HistogramType;
+#ifdef ITK_USE_REVIEW_STATISTICS
+  typedef typename HistogramType::AbsoluteFrequencyType         HistogramFrequencyType;
+#else
   typedef typename HistogramType::FrequencyType         HistogramFrequencyType;
+#endif
   typedef typename HistogramType::Iterator              HistogramIteratorType;
   typedef typename HistogramType::MeasurementVectorType
     HistogramMeasurementVectorType;
