@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNaryMaximumImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:41 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-04-01 14:36:31 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -68,7 +68,7 @@ public:
   
   Maximum1() {}
   ~Maximum1() {}
-  inline TOutput operator()( const std::vector< TInput > & B)
+  inline TOutput operator()( const std::vector< TInput > & B) const
     {
     OutputValueType A = NumericTraits< TOutput >::NonpositiveMin();
     for( unsigned int i=0; i< B.size(); i++ )
@@ -78,17 +78,17 @@ public:
         A = static_cast< OutputValueType > (B[i]);
         }
       }
-      return A;
+    return A;
     }
   
   bool operator== (const Maximum1&) const
-  {
+    {
     return true;
-  }
+    }
   bool operator!= (const Maximum1&) const
-  {
+    {
     return false;
-  }
+    }
 };
 
 }
@@ -101,11 +101,13 @@ NaryFunctorImageFilter<TInputImage,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef NaryMaximumImageFilter  Self;
-  typedef NaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                 Functor::Maximum1< typename TInputImage::PixelType, 
-                                   typename TInputImage::PixelType > >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
+  typedef NaryMaximumImageFilter    Self;
+  typedef NaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Functor::Maximum1< typename TInputImage::PixelType, 
+                       typename TInputImage::PixelType > >
+                                    Superclass;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Method for creation through the object factory. */
