@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRecursiveSeparableImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2005-08-08 19:22:17 $
-  Version:   $Revision: 1.23 $
+  Date:      $Date: 2009-04-25 12:28:01 $
+  Version:   $Revision: 1.26 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -51,26 +51,29 @@ class ITK_EXPORT RecursiveSeparableImageFilter :
 {
 public:
   /** Standard class typedefs. */
-  typedef RecursiveSeparableImageFilter  Self;
+  typedef RecursiveSeparableImageFilter                  Self;
   typedef ImageToImageFilter<TInputImage,TOutputImage>   Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SmartPointer<Self>                             Pointer;
+  typedef SmartPointer<const Self>                       ConstPointer;
 
   /** Type macro that defines a name for this class. */
   itkTypeMacro( RecursiveSeparableImageFilter, ImageToImageFilter );
 
   /** Smart pointer typedef support.  */
-  typedef typename TInputImage::Pointer  InputImagePointer;
+  typedef typename TInputImage::Pointer       InputImagePointer;
   typedef typename TInputImage::ConstPointer  InputImageConstPointer;
 
   /** Real type to be used in internal computations. RealType in general is
    * templated over the pixel type. (For example for vector or tensor pixels,
    * RealType is a vector or a tensor of doubles.) ScalarRealType is a type 
-   * meant for scalars.*/
-  typedef typename TInputImage::PixelType                   InputPixelType;
-  typedef typename NumericTraits<InputPixelType>::RealType  RealType;
+   * meant for scalars.
+   */
+  typedef typename TInputImage::PixelType                        InputPixelType;
+  typedef typename NumericTraits<InputPixelType>::RealType       RealType;
   typedef typename NumericTraits<InputPixelType>::ScalarRealType ScalarRealType;
 
+  typedef typename TOutputImage::RegionType                      OutputImageRegionType;
+
   /** Type of the input image */
   typedef TInputImage      InputImageType;
 
@@ -78,7 +81,7 @@ public:
   typedef TOutputImage      OutputImageType;
 
   /** Get the direction in which the filter is to be applied. */   
-  itkGetMacro(Direction, unsigned int);
+  itkGetConstMacro(Direction, unsigned int);
 
   /** Set the direction in which the filter is to be applied. */   
   itkSetMacro(Direction, unsigned int);
@@ -95,7 +98,10 @@ protected:
   void PrintSelf(std::ostream& os, Indent indent) const;
 
   /** GenerateData (apply) the filter. */   
-  void GenerateData(void);
+  void BeforeThreadedGenerateData();
+  void ThreadedGenerateData(const OutputImageRegionType& outputRegionForThread, int threadId );
+
+  int SplitRequestedRegion(int i, int num, OutputImageRegionType& splitRegion);
 
   /** RecursiveSeparableImageFilter needs all of the input to produce an
    * output. Therefore, RecursiveSeparableImageFilter needs to provide
@@ -122,14 +128,6 @@ protected:
   void FilterDataArray(RealType *outs, const RealType *data, RealType *scratch,
                        unsigned int ln);
 
-private:  
-  RecursiveSeparableImageFilter(const Self&); //purposely not implemented
-  void operator=(const Self&); //purposely not implemented
-
-  /** Direction in which the filter is to be applied
-   * this should be in the range [0,ImageDimension-1]. */ 
-  unsigned int m_Direction;
-
 protected:
   /** Causal coefficients that multiply the input data. */
   ScalarRealType m_N0;
@@ -163,6 +161,14 @@ protected:
   ScalarRealType m_BM3;
   ScalarRealType m_BM4; 
  
+private:  
+  RecursiveSeparableImageFilter(const Self&); //purposely not implemented
+  void operator=(const Self&); //purposely not implemented
+
+  /** Direction in which the filter is to be applied
+   * this should be in the range [0,ImageDimension-1]. */ 
+  unsigned int m_Direction;
+
 };
 
 
