@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSigmoidImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-16 14:41:02 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2009-04-01 14:36:31 $
+  Version:   $Revision: 1.17 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -29,7 +29,7 @@ namespace itk
  * the sigmoid fuction. The resulting total transfrom is given by
  *
  * \f[
- * f(x) = (Max-Min) \cdot \frac{1}{\left(1+e^{-(\frac{ x - \beta }{\alpha}\right)}} + Min
+ * f(x) = (Max-Min) \cdot \frac{1}{\left(1+e^{- \frac{ x - \beta }{\alpha}}\right)} + Min
  * \f]
  *
  * Every output pixel is equal to f(x). Where x is the intensity of the
@@ -44,15 +44,16 @@ template< class TInput, class TOutput>
 class Sigmoid
 {
 public:
-  Sigmoid() { 
+  Sigmoid() 
+    { 
     m_Alpha = 1.0; 
     m_Beta =  0.0; 
     m_OutputMinimum = NumericTraits< TOutput >::min();
     m_OutputMaximum = NumericTraits< TOutput >::max();
-  }
+    }
   ~Sigmoid() {};
   bool operator!=( const Sigmoid & other ) const
-  {
+    {
     if( m_Alpha != other.m_Alpha ||
         m_Beta != other.m_Beta ||
         m_OutputMaximum != other.m_OutputMaximum    ||
@@ -61,44 +62,52 @@ public:
       return true;
       }
     return false;
-  }
+    }
   bool operator==( const Sigmoid & other ) const
-  {
+    {
     return !(*this != other);
-  }
+    }
 
-  inline TOutput operator()( const TInput & A )
-  {
+  inline TOutput operator()( const TInput & A ) const
+    {
     const double x = ( static_cast<double>(A) - m_Beta ) / m_Alpha;
     const double e = 1.0 / ( 1.0 + vcl_exp(- x ) );
     const double v = 
       (m_OutputMaximum - m_OutputMinimum ) * e + m_OutputMinimum;
     return static_cast<TOutput>( v );
-  }
-  void SetAlpha( double alpha ) {
+    }
+  void SetAlpha( double alpha )
+    {
     m_Alpha = alpha;
-  }
-  void SetBeta( double beta ) {
+    }
+  void SetBeta( double beta )
+    {
     m_Beta = beta;
-  }
-  double GetAlpha() const {
+    }
+  double GetAlpha() const
+    {
     return m_Alpha;
-  }
-  double GetBeta() const {
+    }
+  double GetBeta() const
+    {
     return m_Beta;
-  }
-  void SetOutputMinimum( TOutput min ) {
+    }
+  void SetOutputMinimum( TOutput min )
+    {
     m_OutputMinimum = min;
-  }
-  void SetOutputMaximum( TOutput max ) {
+    }
+  void SetOutputMaximum( TOutput max )
+    {
     m_OutputMaximum = max;
-  }
-  TOutput GetOutputMinimum() const {
+    }
+  TOutput GetOutputMinimum() const
+    {
     return m_OutputMinimum;
-  }
-  TOutput GetOutputMaximum() const {
+    }
+  TOutput GetOutputMaximum() const
+    {
     return m_OutputMaximum;
-  }
+    }
 
 private:
   double  m_Alpha;
@@ -119,12 +128,13 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef SigmoidImageFilter  Self;
-  typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                  Function::Sigmoid< typename TInputImage::PixelType, 
-                                                     typename TOutputImage::PixelType> >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SigmoidImageFilter                                Self;
+  typedef UnaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Function::Sigmoid< typename TInputImage::PixelType, 
+                       typename TOutputImage::PixelType> >  Superclass;
+  typedef SmartPointer<Self>                                Pointer;
+  typedef SmartPointer<const Self>                          ConstPointer;
 
   typedef typename TOutputImage::PixelType OutputPixelType;
 
@@ -135,44 +145,44 @@ public:
   itkTypeMacro( SigmoidImageFilter, UnaryFunctorImageFilter );
 
   void SetAlpha( double alpha )
-  {
+    {
     if( alpha == this->GetFunctor().GetAlpha() ) 
       {
       return;
       }
     this->GetFunctor().SetAlpha( alpha );
     this->Modified();
-  }
+    }
 
   void SetBeta( double beta )
-  {
+    {
     if( beta == this->GetFunctor().GetBeta() ) 
       {
       return;
       }
     this->GetFunctor().SetBeta( beta );
     this->Modified();
-  }
+    }
 
   void SetOutputMinimum( OutputPixelType min )
-  {
+    {
     if( min == this->GetFunctor().GetOutputMinimum() ) 
       {
       return;
       }
     this->GetFunctor().SetOutputMinimum( min );
     this->Modified();
-  }
+    }
 
   void SetOutputMaximum( OutputPixelType max )
-  {
+    {
     if( max == this->GetFunctor().GetOutputMaximum() ) 
       {
       return;
       }
     this->GetFunctor().SetOutputMaximum( max );
     this->Modified();
-  }
+    }
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   /** Begin concept checking */
