@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSquareImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:41 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-04-01 14:36:34 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -38,18 +38,18 @@ public:
   Square() {}
   ~Square() {}
   bool operator!=( const Square & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const Square & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput & A )
-  {
+    }
+  inline TOutput operator()( const TInput & A ) const
+    {
     const RealType ra = static_cast<RealType>( A );
     return static_cast<TOutput>( ra * ra );
-  }
+    }
 }; 
 }
 template <class TInputImage, class TOutputImage>
@@ -61,12 +61,13 @@ UnaryFunctorImageFilter<TInputImage,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef SquareImageFilter  Self;
-  typedef UnaryFunctorImageFilter<TInputImage,TOutputImage, 
-                                  Function::Square< typename TInputImage::PixelType, 
-                                                    typename TOutputImage::PixelType> >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
-  typedef SmartPointer<const Self>  ConstPointer;
+  typedef SquareImageFilter                                Self;
+  typedef UnaryFunctorImageFilter<
+    TInputImage,TOutputImage, 
+    Function::Square< typename TInputImage::PixelType, 
+                      typename TOutputImage::PixelType> >  Superclass;
+  typedef SmartPointer<Self>                               Pointer;
+  typedef SmartPointer<const Self>                         ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
