@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVectorAnisotropicDiffusionFunction.h,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:28:58 $
-  Version:   $Revision: 1.13 $
+  Date:      $Date: 2008-10-17 16:30:53 $
+  Version:   $Revision: 1.14 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,8 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
-#ifndef __itkVectorAnisotropicDiffusionFunction_h_
-#define __itkVectorAnisotropicDiffusionFunction_h_
+#ifndef __itkVectorAnisotropicDiffusionFunction_h
+#define __itkVectorAnisotropicDiffusionFunction_h
 
 #include "itkAnisotropicDiffusionFunction.h"
 #include "itkVector.h"
@@ -54,8 +54,8 @@ public:
   /** Standard class typedefs. */
   typedef VectorAnisotropicDiffusionFunction   Self;
   typedef AnisotropicDiffusionFunction<TImage> Superclass;
-  typedef SmartPointer<Self> Pointer;
-  typedef SmartPointer<const Self> ConstPointer;
+  typedef SmartPointer<Self>                   Pointer;
+  typedef SmartPointer<const Self>             ConstPointer;
 
   /** Run-time type information (and related methods) */
   itkTypeMacro(VectorAnisotropicDiffusionFunction,
