@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkXorImageFilter.h,v $
   Language:  C++
-  Date:      $Date: 2007-09-27 11:36:41 $
-  Version:   $Revision: 1.6 $
+  Date:      $Date: 2009-04-01 14:36:37 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -52,17 +52,17 @@ public:
   XOR() {};
   ~XOR() {};
   bool operator!=( const XOR & ) const
-  {
+    {
     return false;
-  }
+    }
   bool operator==( const XOR & other ) const
-  {
+    {
     return !(*this != other);
-  }
-  inline TOutput operator()( const TInput1 & A, const TInput2 & B)
-  {
+    }
+  inline TOutput operator()( const TInput1 & A, const TInput2 & B) const
+    {
     return static_cast<TOutput>( A ^ B );
-  }
+    }
 }; 
 
 }
@@ -79,14 +79,14 @@ BinaryFunctorImageFilter<TInputImage1,TInputImage2,TOutputImage,
 {
 public:
   /** Standard class typedefs. */
-  typedef XorImageFilter  Self;
+  typedef XorImageFilter            Self;
   typedef BinaryFunctorImageFilter<TInputImage1,TInputImage2,TOutputImage, 
                                    Functor::XOR< 
     typename TInputImage1::PixelType, 
     typename TInputImage2::PixelType,
     typename TOutputImage::PixelType>   
-  >  Superclass;
-  typedef SmartPointer<Self>   Pointer;
+  >                                 Superclass;
+  typedef SmartPointer<Self>        Pointer;
   typedef SmartPointer<const Self>  ConstPointer;
 
   /** Method for creation through the object factory. */
