@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAffineTransform.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-25 23:18:04 $
-  Version:   $Revision: 1.68 $
+  Date:      $Date: 2009-04-09 09:23:20 $
+  Version:   $Revision: 1.70 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -99,7 +99,7 @@ namespace itk
  *
  * \ingroup Transforms
  *
- **/
+ */
 
 template <
  class TScalarType=double,         // Data type for scalars 
@@ -151,6 +151,11 @@ public:
   typedef typename Superclass::OffsetType             OffsetType;
   typedef typename Superclass::TranslationType        TranslationType;
 
+  /** Base inverse transform type. This type should not be changed to the
+   * concrete inverse transform type or inheritance would be lost.*/
+  typedef typename Superclass::InverseTransformBaseType InverseTransformBaseType;
+  typedef typename InverseTransformBaseType::Pointer    InverseTransformBasePointer;
+
   /** Compose affine transformation with a translation
    *
    * This method modifies self to include a translation of the
@@ -233,6 +238,12 @@ public:
    * Note that the shear is applied centered at the origin. */
   void Shear(int axis1, int axis2, TScalarType coef, bool pre=0);
 
+  /** Get an inverse of this transform. */
+  bool GetInverse(Self* inverse) const;
+
+  /** Return an inverse of this transform. */
+  virtual InverseTransformBasePointer GetInverseTransform() const;
+
   /** Back transform by an affine transformation
    *
    * This method finds the point or vector that maps to a given
@@ -240,7 +251,7 @@ public:
    * self.  If no such point exists, an exception is thrown.   
    *
    * \deprecated Please use GetInverseTransform and then call the
-   *   forward transform function **/
+   *   forward transform function */
   inline InputPointType   BackTransform(const OutputPointType  &point ) const;
   inline InputVectorType  BackTransform(const OutputVectorType &vector) const;
   inline InputVnlVectorType BackTransform(
@@ -256,7 +267,7 @@ public:
    * pointer to) a brand new point created with new. 
    *
    * \deprecated Please use GetInverseTransform and then call the
-   *   forward transform function **/
+   *   forward transform function */
   inline InputPointType BackTransformPoint(const OutputPointType  &point) const;
 
   /** Compute distance between two affine transformations
@@ -274,7 +285,7 @@ public:
 
   /** This method computes the distance from self to the identity
    * transformation, using the same metric as the one-argument form
-   * of the Metric() method. **/
+   * of the Metric() method. */
   ScalarType Metric(void) const;
 
 protected:
@@ -284,14 +295,14 @@ protected:
    * initializes the matrix and offset parts of the transformation
    * to values specified by the caller.  If the arguments are
    * omitted, then the AffineTransform is initialized to an identity
-   * transformation in the appropriate number of dimensions.   **/
+   * transformation in the appropriate number of dimensions.   */
   AffineTransform(const MatrixType &matrix,
                   const OutputVectorType &offset);
   AffineTransform(unsigned int outputDims,
                   unsigned int paramDims);
   AffineTransform();
   
-  /** Destroy an AffineTransform object   **/
+  /** Destroy an AffineTransform object   */
   virtual ~AffineTransform();
 
   /** Print contents of an AffineTransform */
