@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCenteredSimilarity2DTransform.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-30 20:56:07 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-04-09 09:23:20 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -105,6 +105,11 @@ public:
   /** VnlVector type. */
   typedef typename Superclass::InputVnlVectorType   InputVnlVectorType;
   typedef typename Superclass::OutputVnlVectorType  OutputVnlVectorType;
+
+  /** Base inverse transform type. This type should not be changed to the
+   * concrete inverse transform type or inheritance would be lost.*/
+  typedef typename Superclass::InverseTransformBaseType InverseTransformBaseType;
+  typedef typename InverseTransformBaseType::Pointer    InverseTransformBasePointer;
   
   /** Set the transformation from a container of parameters
     * This is typically used by optimizers.
@@ -144,14 +149,18 @@ public:
 
   /**
    * This method creates and returns a new Rigid2DTransform object
-   * which is the inverse of self.
-   **/
+   * which is the inverse of self. */
   void CloneInverseTo( Pointer & newinverse ) const;
 
+  /** Get an inverse of this transform. */
+  bool GetInverse(Self* inverse) const;
+
+  /** Return an inverse of this transform. */
+  virtual InverseTransformBasePointer GetInverseTransform() const;
+
   /**
    * This method creates and returns a new Rigid2DTransform object
-   * which has the same parameters.
-   **/
+   * which has the same parameters. */
   void CloneTo( Pointer & clone ) const;
 
 protected:
@@ -171,7 +180,7 @@ private:
 
 }  // namespace itk
 
-// Define instantiation macro for this template.
+/* Define instantiation macro for this template. */
 #define ITK_TEMPLATE_CenteredSimilarity2DTransform(_, EXPORT, x, y) namespace itk { \
   _(1(class EXPORT CenteredSimilarity2DTransform< ITK_TEMPLATE_1 x >)) \
   namespace Templates { typedef CenteredSimilarity2DTransform< ITK_TEMPLATE_1 x > \
