@@ -3,14 +3,14 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkImageConstIteratorWithIndex.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-30 20:56:08 $
-  Version:   $Revision: 1.24 $
+  Date:      $Date: 2008-10-17 01:41:59 $
+  Version:   $Revision: 1.25 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
 
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
+     This software is distributed WITHOUT ANY WARRANTY; without even
+     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
@@ -40,7 +40,7 @@ namespace itk
  * construction and comparison operations. It does not provide mechanisms for
  * moving the iterator.  A subclass of ImageConstIteratorWithIndex must be used
  * to move the iterator.
- * 
+ *
  * ImageConstIteratorWithIndex is a multi-dimensional iterator, requiring
  * more information be specified before the iterator can be used than
  * conventional iterators.  Whereas the std::vector::iterator from the
@@ -65,25 +65,25 @@ namespace itk
  *
  * \sa ImageConstIterator \sa ConditionalConstIterator
  * \sa ConstNeighborhoodIterator \sa ConstShapedNeighborhoodIterator
- * \sa ConstSliceIterator  \sa CorrespondenceDataStructureIterator 
- * \sa FloodFilledFunctionConditionalConstIterator 
- * \sa FloodFilledImageFunctionConditionalConstIterator 
- * \sa FloodFilledImageFunctionConditionalIterator 
- * \sa FloodFilledSpatialFunctionConditionalConstIterator 
- * \sa FloodFilledSpatialFunctionConditionalIterator 
- * \sa ImageConstIterator \sa ImageConstIteratorWithIndex 
+ * \sa ConstSliceIterator  \sa CorrespondenceDataStructureIterator
+ * \sa FloodFilledFunctionConditionalConstIterator
+ * \sa FloodFilledImageFunctionConditionalConstIterator
+ * \sa FloodFilledImageFunctionConditionalIterator
+ * \sa FloodFilledSpatialFunctionConditionalConstIterator
+ * \sa FloodFilledSpatialFunctionConditionalIterator
+ * \sa ImageConstIterator \sa ImageConstIteratorWithIndex
  * \sa ImageIterator \sa ImageIteratorWithIndex
- * \sa ImageLinearConstIteratorWithIndex  \sa ImageLinearIteratorWithIndex 
- * \sa ImageRandomConstIteratorWithIndex  \sa ImageRandomIteratorWithIndex 
- * \sa ImageRegionConstIterator \sa ImageRegionConstIteratorWithIndex 
- * \sa ImageRegionExclusionConstIteratorWithIndex 
- * \sa ImageRegionExclusionIteratorWithIndex 
- * \sa ImageRegionIterator  \sa ImageRegionIteratorWithIndex 
- * \sa ImageRegionReverseConstIterator  \sa ImageRegionReverseIterator 
- * \sa ImageReverseConstIterator  \sa ImageReverseIterator 
- * \sa ImageSliceConstIteratorWithIndex  \sa ImageSliceIteratorWithIndex 
- * \sa NeighborhoodIterator \sa PathConstIterator  \sa PathIterator 
- * \sa ShapedNeighborhoodIterator  \sa SliceIterator 
+ * \sa ImageLinearConstIteratorWithIndex  \sa ImageLinearIteratorWithIndex
+ * \sa ImageRandomConstIteratorWithIndex  \sa ImageRandomIteratorWithIndex
+ * \sa ImageRegionConstIterator \sa ImageRegionConstIteratorWithIndex
+ * \sa ImageRegionExclusionConstIteratorWithIndex
+ * \sa ImageRegionExclusionIteratorWithIndex
+ * \sa ImageRegionIterator  \sa ImageRegionIteratorWithIndex
+ * \sa ImageRegionReverseConstIterator  \sa ImageRegionReverseIterator
+ * \sa ImageReverseConstIterator  \sa ImageReverseIterator
+ * \sa ImageSliceConstIteratorWithIndex  \sa ImageSliceIteratorWithIndex
+ * \sa NeighborhoodIterator \sa PathConstIterator  \sa PathIterator
+ * \sa ShapedNeighborhoodIterator  \sa SliceIterator
  *
  * \ingroup ImageIterators
  */
@@ -117,9 +117,9 @@ public:
   /** PixelContainer typedef support. Used to refer to the container for
    * the pixel data. While this was already typdef'ed in the superclass
    * it needs to be redone here for this subclass to compile properly with gcc. */
-  typedef typename TImage::PixelContainer PixelContainer;
-  typedef typename PixelContainer::Pointer PixelContainerPointer;
-  
+  typedef typename TImage::PixelContainer       PixelContainer;
+  typedef typename PixelContainer::Pointer      PixelContainerPointer;
+
   /** Internal Pixel Type */
   typedef typename TImage::InternalPixelType   InternalPixelType;
 
@@ -151,9 +151,9 @@ public:
   /** operator= is provided to make sure the handle to the image is properly
    * reference counted. */
   Self &operator=(const Self& it);
-  
+
   /** Get the dimension (size) of the index. */
-  static unsigned int GetImageDimension() 
+  static unsigned int GetImageDimension()
     {return ImageDimension;}
 
   /** Comparison operator. Two iterators are the same if they "point to" the
@@ -163,7 +163,7 @@ public:
     {
     // two iterators are the same if they "point to" the same memory location
     return (m_Position) != (it.m_Position);
-    };
+    }
 
   /** Comparison operator. Two iterators are the same if they "point to" the
    * same memory location */
@@ -172,8 +172,8 @@ public:
     {
     // two iterators are the same if they "point to" the same memory location
     return (m_Position) == (it.m_Position);
-    };
-  
+    }
+
   /** Comparison operator. An iterator is "less than" another if it "points to"
    * a lower memory location. */
   bool
@@ -182,7 +182,7 @@ public:
     // an iterator is "less than" another if it "points to" a lower
     // memory location
     return (m_Position) <= (it.m_Position);
-    };
+    }
 
   /** Comparison operator. An iterator is "less than" another if it "points to"
    * a lower memory location. */
@@ -192,7 +192,7 @@ public:
     // an iterator is "less than" another if it "points to" a lower
     // memory location
     return (m_Position) < (it.m_Position);
-    };
+    }
 
   /** Comparison operator. An iterator is "greater than" another if it
    * "points to" a higher location. */
@@ -202,7 +202,7 @@ public:
     // an iterator is "greater than" another if it "points to" a higher
     // memory location
     return (m_Position) >= (it.m_Position);
-    };
+    }
 
   /** Comparison operator. An iterator is "greater than" another if it
    * "points to" a higher location. */
@@ -212,7 +212,7 @@ public:
     // an iterator is "greater than" another if it "points to" a higher
     // memory location
     return (m_Position) > (it.m_Position);
-    };
+    }
 
   /** Get the index. This provides a read only reference to the index.
    * \sa SetIndex */
@@ -222,24 +222,26 @@ public:
   /** Get the region that this iterator walks. ImageIterators know the
    * beginning and the end of the region of the image to iterate over. */
   const RegionType& GetRegion() const
-    { return m_Region; };
+    { return m_Region; }
 
   /** Set the index. No bounds checking is performed.
    * \sa GetIndex */
   void SetIndex(const IndexType &ind)
-  { m_Position = m_Image->GetBufferPointer() + m_Image->ComputeOffset( ind ); 
-      m_PositionIndex = ind;  }
+    {
+    m_Position = m_Image->GetBufferPointer() + m_Image->ComputeOffset( ind );
+    m_PositionIndex = ind;
+    }
 
   /** Get the pixel value */
-  PixelType Get(void) const  
+  PixelType Get(void) const
     { return m_PixelAccessorFunctor.Get(*m_Position); }
-  
-  /** Return a const reference to the pixel 
+
+  /** Return a const reference to the pixel
    * This method will provide the fastest access to pixel
    * data, but it will NOT support ImageAdaptors. */
-  const PixelType & Value(void) const  
+  const PixelType & Value(void) const
     { return *m_Position; }
- 
+
   /** Move an iterator to the beginning of the region.
    * \deprecated Use GoToBegin() instead */
   Self Begin(void) const;
@@ -257,24 +259,24 @@ public:
   /** Is the iterator at the beginning of the region? */
   bool IsAtReverseEnd(void) const
     {
-      return !m_Remaining;
+    return !m_Remaining;
     }
 
   /** Is the iterator at the end of the region? */
   bool IsAtEnd(void) const
     {
-      return !m_Remaining;
+    return !m_Remaining;
     }
-  
- /** Are there data remainning in the region ? */
+
+  /** Are there data remainning in the region ? */
   bool Remaining()
     {
     return m_Remaining;
     }
-  
-protected: //made protected so other iterators can access 
+
+protected: //made protected so other iterators can access
   typename TImage::ConstWeakPointer     m_Image;
-  
+
   IndexType    m_PositionIndex;     // Index where we currently are
   IndexType    m_BeginIndex;        // Index to start iterating over
   IndexType    m_EndIndex;          // Index to finish iterating:
@@ -283,8 +285,8 @@ protected: //made protected so other iterators can access
 
   RegionType   m_Region;            // region to iterate over
 
-  unsigned long          m_OffsetTable[ ImageDimension + 1 ]; 
-  
+  unsigned long          m_OffsetTable[ ImageDimension + 1 ];
+
   const InternalPixelType     *m_Position;
   const InternalPixelType     *m_Begin;
   const InternalPixelType     *m_End;
@@ -313,4 +315,4 @@ protected: //made protected so other iterators can access
 # include "itkImageConstIteratorWithIndex.txx"
 #endif
 
-#endif 
+#endif
