@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRigid3DTransform.h,v $
   Language:  C++
-  Date:      $Date: 2007-02-13 21:46:04 $
-  Version:   $Revision: 1.38 $
+  Date:      $Date: 2009-04-09 09:23:21 $
+  Version:   $Revision: 1.40 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,7 +26,8 @@
 namespace itk
 {
 
-/** \brief Rigid3DTransform of a vector space (e.g. space coordinates)
+/** \class Rigid3DTransform
+ * \brief Rigid3DTransform of a vector space (e.g. space coordinates)
  *
  * This transform applies a rotation and translation in 3D space.
  * The transform is specified as a rotation matrix around a arbitrary center
@@ -74,9 +75,9 @@ public:
   typedef typename Superclass::InputVectorType            InputVectorType;
   typedef typename Superclass::OutputVectorType           OutputVectorType;
   typedef typename Superclass::InputCovariantVectorType  
-                                                     InputCovariantVectorType;
+                                                          InputCovariantVectorType;
   typedef typename Superclass::OutputCovariantVectorType  
-                                                     OutputCovariantVectorType;
+                                                          OutputCovariantVectorType;
   typedef typename Superclass::InputVnlVectorType         InputVnlVectorType;
   typedef typename Superclass::OutputVnlVectorType        OutputVnlVectorType;
   typedef typename Superclass::InputPointType             InputPointType;
@@ -87,6 +88,11 @@ public:
   typedef typename Superclass::TranslationType            TranslationType;
   typedef typename Superclass::OffsetType                 OffsetType;
 
+  /** Base inverse transform type. This type should not be changed to the
+   * concrete inverse transform type or inheritance would be lost.*/
+  typedef typename Superclass::InverseTransformBaseType InverseTransformBaseType;
+  typedef typename InverseTransformBaseType::Pointer    InverseTransformBasePointer;
+
   /** Set the transformation from a container of parameters
    * This is typically used by optimizers.
    * There are 12 parameters. The first 9 represents the rotation
@@ -113,9 +119,9 @@ public:
    * Rigid3DTransform.
    *
    * \deprecated Use GetMatrix instead
-   **/
-   const MatrixType & GetRotationMatrix()
-     { return this->GetMatrix(); }
+   */
+  const MatrixType & GetRotationMatrix()
+    { return this->GetMatrix(); }
 
   /**
    * Set the rotation Matrix of a Rigid3D Transform
@@ -126,7 +132,7 @@ public:
    *
    * \deprecated Use SetMatrix instead
    * 
-   **/
+   */
   virtual void SetRotationMatrix(const MatrixType & matrix)
       { this->SetMatrix(matrix); }
 
@@ -136,9 +142,15 @@ public:
    * This method modifies self to include a translation of the
    * origin.  The translation is precomposed with self if pre is
    * true, and postcomposed otherwise.
-   **/
+   */
   void Translate(const OffsetType & offset, bool pre=false);
 
+  /** Get an inverse of this transform. */
+  bool GetInverse(Self* inverse) const;
+
+  /** Return an inverse of this transform. */
+  virtual InverseTransformBasePointer GetInverseTransform() const;
+
   /**
    * Back transform by an affine transformation
    *
@@ -149,7 +161,7 @@ public:
    * \deprecated Please use GetInverseTransform and then call the forward
    *   transform using the result.
    *
-   **/
+   */
   InputPointType      BackTransform(const OutputPointType 
                                                    &point ) const;
   InputVectorType     BackTransform(const OutputVectorType 
@@ -159,10 +171,10 @@ public:
   InputCovariantVectorType BackTransform(const OutputCovariantVectorType
                                                    &vector) const;
 
-   /**
-    * Utility function to test if a matrix is orthogonal within a specified 
-    * tolerance
-    */
+  /**
+   * Utility function to test if a matrix is orthogonal within a specified 
+   * tolerance
+   */
   bool MatrixIsOrthogonal( const MatrixType & matrix, double tol = 1e-10 );
 
 protected:
@@ -175,7 +187,7 @@ protected:
   
   /**
    * Print contents of an Rigid3DTransform
-   **/
+   */
   void PrintSelf(std::ostream &os, Indent indent) const;
 
 private:
