@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTreeIteratorClone.h,v $
   Language:  C++
-  Date:      $Date: 2004-07-23 20:07:14 $
-  Version:   $Revision: 1.1 $
+  Date:      $Date: 2009-03-03 15:10:40 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -30,7 +30,7 @@ public:
   
   /** Typedefs */
   typedef TreeIteratorClone<TObjectType> Self;
-  typedef TObjectType ObjectType;
+  typedef TObjectType                    ObjectType;
   
   /** Constructor  */
   TreeIteratorClone () 
@@ -41,7 +41,7 @@ public:
   /** Copy constructor  */
   TreeIteratorClone (const TreeIteratorClone<ObjectType> &p)
     { 
-
+    m_Pointer = 0;
     if(p.m_Pointer != NULL)
       {
       m_Pointer = p.m_Pointer->Clone();
@@ -52,18 +52,18 @@ public:
   TreeIteratorClone (ObjectType *p)
     { 
     m_Pointer = 0;
-    if(p!=NULL)
+    if(p!=NULL) 
       {
       m_Pointer=p->Clone();
       }
-    }                             
-
+    }
+  
   /** Constructor to reference p  */
   TreeIteratorClone (const ObjectType &p)
     { 
     m_Pointer = 0;
     m_Pointer=const_cast<ObjectType*>(&p)->Clone();
-    }                             
+    }
   
   /** Destructor  */
   ~TreeIteratorClone ()
@@ -78,17 +78,17 @@ public:
 
   /** Test if the pointer has been initialized */
   bool IsNotNull() const
-  { return m_Pointer != 0; }
+    { return m_Pointer != 0; }
   bool IsNull() const
-  { return m_Pointer == 0; }
+    { return m_Pointer == 0; }
 
   /** Template comparison operators. */
-  template <typename R>
-  bool operator == ( R r ) const
+  template <typename TR>
+  bool operator == ( TR r ) const
     { return (m_Pointer == (ObjectType*)(r) ); }
 
-  template <typename R>
-  bool operator != ( R r ) const
+  template <typename TR>
+  bool operator != ( TR r ) const
     { return (m_Pointer != (ObjectType*)(r) ); }
     
   /** Access function to pointer. */
@@ -117,7 +117,7 @@ public:
   
   /** Overload operator assignment.  */
   TreeIteratorClone &operator = (const ObjectType *r)
-    {                                                              
+    {
     if (m_Pointer != r)
       {
       delete m_Pointer;
@@ -132,10 +132,23 @@ public:
   operator++()
     {
     if(m_Pointer)
+      {
       ++(*m_Pointer);
+      }
     return *this;
     }
-  
+
+  const Self
+  operator++(int)
+    {
+    if(m_Pointer)
+      {
+      const Self oldValue( m_Pointer ); // create a copy of the iterator behind the pointer (Clone())
+      ++(*m_Pointer);
+      return oldValue;
+      }
+    }
+   
   /** Function to print object pointed to  */
   ObjectType *Print (std::ostream& os) const 
     { 
