@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkWin32Header.h,v $
   Language:  C++
-  Date:      $Date: 2006-03-18 18:06:38 $
-  Version:   $Revision: 1.30 $
+  Date:      $Date: 2008-05-19 14:34:10 $
+  Version:   $Revision: 1.32 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -59,7 +59,6 @@
 // clients of class 'type2'
 #pragma warning ( disable : 4251 )
 
-
 // non dll-interface class 'type' used as base for dll-interface class 'type2'
 #pragma warning ( disable : 4275 )
 
@@ -70,6 +69,12 @@
 // 'type' : inconsistent dll linkage.  dllexport assumed.
 #pragma warning ( disable : 4273 )
 
+// conditional expression is constant
+#pragma warning ( disable : 4127 )
+
+// unreferenced local function has been removed
+#pragma warning ( disable : 4505 )
+
 
 // typename keyword in default template arguments is not accepted by
 // MSVC.  This macro should only be used in such places.
@@ -82,7 +87,8 @@
 # define ITK_TYPENAME typename
 #endif
 
-// ITK_EXPORT can not be used
+// When a class definition has ITK_EXPORT, the class will be
+// checked automatically, by Utilities/Dart/PrintSelfCheck.tcl
 #define ITK_EXPORT
 
 #if (defined(_WIN32) || defined(WIN32)) && !defined(ITKSTATIC) 
