@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBMPImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-03-10 23:59:06 $
-  Version:   $Revision: 1.26 $  
+  Date:      $Date: 2009-05-26 23:45:03 $
+  Version:   $Revision: 1.31 $  
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -43,10 +43,18 @@ BMPImageIO::BMPImageIO()
   m_Origin[1] = 0.0;
   m_FileLowerLeft = 0;
   m_Depth = 8;
-  m_Allow8BitBMP = true;
+  m_Allow8BitBMP = false;
   m_NumberOfColors = 0;
+  m_ColorTableSize = 0;
   m_BMPCompression = 0;
   m_BMPDataSize = 0;
+
+  this->AddSupportedWriteExtension(".bmp");
+  this->AddSupportedWriteExtension(".BMP");
+
+  this->AddSupportedReadExtension(".bmp");
+  this->AddSupportedReadExtension(".BMP");
+
 }
 
 
@@ -257,11 +265,12 @@ void BMPImageIO::Read(void* buffer)
       }
     else
       {
+      // File is not compressed
+      // Read one row at a time
       for(unsigned int id=0;id<m_Dimensions[1];id++)
         {
         m_Ifstream.seekg(m_BitMapOffset + paddedStreamRead*(m_Dimensions[1] - id - 1),std::ios::beg);
         m_Ifstream.read((char *)value, paddedStreamRead);
-
         for(long i=0;i<streamRead;i++)
           {
           if(this->GetNumberOfComponents() == 1)
@@ -270,7 +279,7 @@ void BMPImageIO::Read(void* buffer)
             }
           else
             {
-            if(m_NumberOfColors == 0)
+            if(m_ColorTableSize == 0)
               {
               if(this->GetNumberOfComponents() == 3 )
                 {
@@ -311,6 +320,7 @@ void BMPImageIO::Read(void* buffer)
       }
     }
   else
+    // File not lower left
     {
     m_Ifstream.seekg(m_BitMapOffset,std::ios::beg);
     for(unsigned int id=0;id<m_Dimensions[1];id++)
@@ -399,7 +409,6 @@ void BMPImageIO::ReadImageInformation()
     {
     m_Ifstream.read((char*)&infoSize,4);
     ByteSwapper<long>::SwapFromSystemToLittleEndian(&infoSize);
-                       
     // error checking
     if ((infoSize != 40)&&(infoSize != 12))
       {
@@ -537,10 +546,24 @@ void BMPImageIO::ReadImageInformation()
       m_Ifstream.read((char*)&itmp,4);
       }
     }
-
-  // Read the color palette
+  // Read the color palette. Only used for 1,4 and 8 bit images.
+  if (m_Depth <= 8)
+    {
+    if (m_NumberOfColors)
+      {
+      m_ColorTableSize = ((1 << m_Depth) < m_NumberOfColors) ? (1 << m_Depth) : m_NumberOfColors;
+      }
+    else
+      {
+      m_ColorTableSize = (1 << m_Depth);
+      }
+    }
+  else
+    {
+    m_ColorTableSize = 0;
+    }
   unsigned char uctmp;
-  for(unsigned long i=0;i<m_NumberOfColors;i++)
+  for(unsigned long i=0;i<m_ColorTableSize;i++)
     {
     RGBPixelType p;
     m_Ifstream.read((char*)&uctmp,1);
@@ -555,6 +578,8 @@ void BMPImageIO::ReadImageInformation()
 
   switch( m_Depth )
     {
+    case 1:
+    case 4:
     case 8:
       {
       if( m_Allow8BitBMP )
@@ -562,6 +587,11 @@ void BMPImageIO::ReadImageInformation()
         this->SetNumberOfComponents(1);
         m_PixelType = SCALAR;
         }
+      else
+        {
+        this->SetNumberOfComponents(3);
+        m_PixelType = RGB;
+        }
       break;
       }
     case 24:
@@ -657,11 +687,11 @@ BMPImageIO
   char tmp;
   tmp = value%256;
   m_Ofstream.write(&tmp,sizeof(char));
-  tmp = (value%65536L)/256;
+  tmp = static_cast<char>((value%65536L)/256);
   m_Ofstream.write(&tmp,sizeof(char));
-  tmp = (value/65536L)%256;
+  tmp = static_cast<char>((value/65536L)%256);
   m_Ofstream.write(&tmp,sizeof(char));
-  tmp = (value/65536L)/256;
+  tmp = static_cast<char>((value/65536L)/256);
   m_Ofstream.write(&tmp,sizeof(char));
 }
 
@@ -672,7 +702,7 @@ BMPImageIO
   char tmp;
   tmp = value%256;
   m_Ofstream.write(&tmp,sizeof(char));
-  tmp = (value%65536L)/256;
+  tmp = static_cast<char>((value%65536L)/256);
   m_Ofstream.write(&tmp,sizeof(char));
 }
 
@@ -768,7 +798,7 @@ BMPImageIO
     }
   const unsigned long paddedBytes = bytesPerRow - (m_Dimensions[0]*bpp);
 
-  const unsigned int rawImageDataSize = ( bytesPerRow * m_Dimensions[1]);
+  const unsigned int rawImageDataSize = static_cast<unsigned int>(( bytesPerRow * m_Dimensions[1]));
   unsigned int fileSize = ( rawImageDataSize ) + 54;
   if( bpp == 1 ) 
     {
@@ -847,10 +877,17 @@ BMPImageIO
   // The specification calls for a signed integer, but
   // here we force it to be an unsigned integer to avoid
   // dealing with directions in a subterraneous way.
+#ifdef ITK_USE_PORTABLE_ROUND
+  const unsigned int horizontalResolution = 
+    static_cast<unsigned int>( Math::Round( 1000.0 / m_Spacing[0] ) );
+  const unsigned int verticalResolution =
+    static_cast<unsigned int>( Math::Round( 1000.0 / m_Spacing[1] ) );
+#else
   const unsigned int horizontalResolution = 
     static_cast<unsigned int>( vnl_math_rnd( 1000.0 / m_Spacing[0] ) );
   const unsigned int verticalResolution =
     static_cast<unsigned int>( vnl_math_rnd( 1000.0 / m_Spacing[1] ) );
+#endif
 
   this->Write32BitsInteger( horizontalResolution );
   this->Write32BitsInteger( verticalResolution );
