@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkIOCommon.h,v $
   Language:  C++
-  Date:      $Date: 2007-12-03 13:13:10 $
-  Version:   $Revision: 1.25 $
+  Date:      $Date: 2008-05-27 11:41:08 $
+  Version:   $Revision: 1.27 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -65,18 +65,35 @@ public:
   /** Calculate the size, in bytes, that the atomic pixel type occupies. */
   static unsigned int ComputeSizeOfAtomicPixelType(const AtomicPixelType pixelType);
 
-  /** Given a full filename, extracts just the pathname. */
-  static char* ExtractFilePath (const char* fileName);
+  /** Given a full filename, extracts just the pathname.  
+   *
+   * \deprecated in ITK 3.8, please use
+   * itksys::SystemTools::GetFilenamePath(fileName) instead.
+   */
+  itkLegacyMacro( static char* ExtractFilePath (const char* fileName) );
 
-  /** Given a full filename, extracts just the file extension. */
-  static char* ExtractFileExtension (const char* fileName);
+  /** Given a full filename, extracts just the file extension.
+   *
+   * \deprecated in ITK 3.8, please use
+   * itksys::SystemTools::GetFilenameExtension(fileName) or
+   * itksys::SystemTools::GetFilenameLastExtension(fileName) instead.
+   */
+  itkLegacyMacro( static char* ExtractFileExtension (const char* fileName) );
 
-  /** Given a full filename, extracts just the filename. */
-  static char* ExtractFileName (const char* fileName);
+  /** Given a full filename, extracts just the filename.
+   *
+   * \deprecated in ITK 3.8, please use
+   * itksys::SystemTools::GetFilenameName(fileName) instead.
+   */
+  itkLegacyMacro( static char* ExtractFileName (const char* fileName) );
 
-  /** Given a filename determine whether it exists and 
-       * return true if it does. */
-  static bool FileExists(const char* filename);
+  /** Given a filename determine whether it exists and return true if
+   * it does.
+   *
+   * \deprecated in ITK 3.8, please use
+   * itksys::SystemTools::FileExists(fileName) instead.
+   */
+  itkLegacyMacro( static bool FileExists(const char* filename) );
 
 };
   
