@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkTIFFImageIO.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-03-27 20:31:12 $
-  Version:   $Revision: 1.60 $
+  Date:      $Date: 2009-04-05 10:56:48 $
+  Version:   $Revision: 1.65 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -23,6 +23,8 @@
 #include "itkRGBAPixel.h"
 #include <itksys/SystemTools.hxx>
 #include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 
 #include <sys/stat.h>
 
@@ -1376,6 +1378,17 @@ TIFFImageIO::TIFFImageIO()
   m_Origin[1] = 0.0;
 
   m_Compression = TIFFImageIO::PackBits;
+
+  this->AddSupportedWriteExtension(".tif");
+  this->AddSupportedWriteExtension(".TIF");
+  this->AddSupportedWriteExtension(".tiff");
+  this->AddSupportedWriteExtension(".TIFF");
+
+  this->AddSupportedReadExtension(".tif");
+  this->AddSupportedReadExtension(".TIF");
+  this->AddSupportedReadExtension(".tiff");
+  this->AddSupportedReadExtension(".TIFF");
+
 }
 
 TIFFImageIO::~TIFFImageIO()
@@ -1630,16 +1643,16 @@ public:
         out->seekp(off, std::ios::cur);
         break;
       default:
-        return out->tellp();
+        return static_cast<toff_t>(out->tellp());
       }
-    return out->tellp();
+    return static_cast<toff_t>(out->tellp());
     }
 
   static toff_t TIFFSize(thandle_t fd)
     {
     std::ostream *out = reinterpret_cast<std::ostream *>(fd);
     out->seekp(0, std::ios::end);
-    return out->tellp();
+    return static_cast<toff_t>(out->tellp());
     }
 
   static int TIFFMapFile(thandle_t, tdata_t*, toff_t*) { return (0); }
