@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkFEMLinearSystemWrappers.h,v $
   Language:  C++
-  Date:      $Date: 2006-11-07 23:23:16 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-01-30 21:10:12 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -14,6 +14,8 @@
      PURPOSE.  See the above copyright notices for more information.
 
 =========================================================================*/
+#ifndef __itkFEMLinearSystemWrappers_h
+#define __itkFEMLinearSystemWrappers_h
 
 /**
  * \file itkFEMLinearSystemWrappers.h
@@ -25,3 +27,4 @@
 #include "itkFEMLinearSystemWrapperItpack.h"
 #include "itkFEMLinearSystemWrapperVNL.h"
 #include "itkFEMLinearSystemWrapperDenseVNL.h"
+#endif
