@@ -3,8 +3,8 @@
 Program:   Insight Segmentation & Registration Toolkit
 Module:    $RCSfile: itkMultivariateLegendrePolynomial.h,v $
 Language:  C++
-Date:      $Date: 2007-03-22 14:29:13 $
-Version:   $Revision: 1.24 $
+Date:      $Date: 2009-05-12 17:19:47 $
+Version:   $Revision: 1.27 $
 
 Copyright (c) Insight Software Consortium. All rights reserved.
 See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -28,22 +28,23 @@ namespace itk {
  *
  * In 2D, 
  * \f[
- *  f(x_vector, parameter_vector) 
- * = sum_i (sum_j (parameter_{ i j } * P_i(x) *P_j(y)) 
- * over j from 0 to l - i)) over i from 0 to l 
+ *  f(x_{vector}, parameter_{vector}) =
+ * \sum_i^l \left( 
+ * \sum_j^{l-i} \left( parameter_ {ij} * P_i(x) *P_j(y)) \right) \right)  
  * \f]
  * where P_i() denoting a Legendre polynomial of degree i
  * and l it the degree of the polynomial
  *
  * In 3D,
  * \f[
- * f(x_vector, parameter_vecter)
- * = sum_i (sum_j (sum_k (parameter_{i j k} * P_i(x) * P_j(y) * P_k(z)) 
- * over k from 0 to l - i - j) over j from 0 to l - i) over i from 0 to l
+ * f(x_{vector}, parameter_{vector}) =
+ * \sum_i^l \left( \sum_j^{l-i} \left( \sum_k^{l-i-j} \left( 
+ * parameter_{ijk} * P_i(x) * P_j(y) * P_k(z) \right) \right) \right) 
  * \f]
  *
- * The size of the parameter vector for 2D is \f$ (l + 1) * (l + 2) / 2 \f$,
- * and for 3D is \f$ (l + 1) * (l + 2) / 2 * (l + 3) / 3 \f$
+ * The size of the parameter vector for 2D is 
+ * \f$\frac{(l+1)\cdot(1+2)}{2}\f$,
+ * and for 3D is \f$\frac{(l+1)*(l+2)*(l+3){3!}\f$
  *
  * To get the size of the parameter vector, users can use one of the 
  * two GetNumberOfCoefficients() member functions
@@ -56,7 +57,7 @@ namespace itk {
  * by Martin Styner, Univ. of North Carolina at Chapel Hill, and his
  * colleagues.
  *
- * For more details. refer to the following articles.
+ * \note For more details. refer to the following articles.
  * "Parametric estimate of intensity inhomogeneities applied to MRI" 
  * Martin Styner, G. Gerig, Christian Brechbuehler, Gabor Szekely,  
  * IEEE TRANSACTIONS ON MEDICAL IMAGING; 19(3), pp. 153-165, 2000, 
@@ -67,7 +68,7 @@ namespace itk {
  * (http://www.ia.unc.edu/~styner/docs/StynerTR97.pdf)
  */
 
-class MultivariateLegendrePolynomial
+class ITK_EXPORT MultivariateLegendrePolynomial
 {
 public:
   typedef MultivariateLegendrePolynomial Self;
@@ -106,7 +107,8 @@ public:
    *  This number is computed from the degree of the polynomial 
    *  the SetCoefficients() method expects an array of this 
    *  size, an exception is thrown otherwise
-   *  \sa SetCoefficients                                   */
+   *  \sa SetCoefficients
+   */
   unsigned int GetNumberOfCoefficients(void) const
     { return m_NumberOfCoefficients; }
 
@@ -114,9 +116,9 @@ public:
   const DomainSizeType & GetDomainSize( void ) const 
     { return m_DomainSize; }
 
-  /** Exception object. */
+  /** \class CoefficientVectorSizeMismatch Exception object. */
   class CoefficientVectorSizeMismatch 
-  {
+    {
   public:
     CoefficientVectorSizeMismatch(int given, int required)
       {
@@ -126,9 +128,9 @@ public:
     
     int m_Required;
     int m_Given;
-  };
+    };
 
-  /** Sets the Legendre polynomials' parameters. 
+  /** \brief Sets the Legendre polynomials' parameters. 
    * \warning The number of coefficients provided should
    * match the number returned by GetNumberOfCoefficients()
    * otherwise an exception is thrown.  */
@@ -138,13 +140,13 @@ public:
   void SetCoefficients(const ParametersType& coef) 
     throw (CoefficientVectorSizeMismatch);
 
-  /** Gets Legendre polynomials' coefficients. */
+  /** \brief Gets Legendre polynomials' coefficients. */
   const CoefficientArrayType& GetCoefficients(void) const;
  
   /** In the case which the bias field is 2D, it returns bias value at
    * the point which is specified by the index */
   double Evaluate(IndexType& index) 
-  {
+    {
     if (m_Dimension == 2)
       {
       if (index[1] != m_PrevY)
@@ -188,7 +190,7 @@ public:
       return this->LegendreSum(norm_x, m_Degree, m_CachedXCoef);
       }
     return 0;
-  }
+    }
 
   /** Gets the number of coefficients. */
   unsigned int GetNumberOfCoefficients();
@@ -196,34 +198,37 @@ public:
   /** Gets the number of coefficients. */
   unsigned int GetNumberOfCoefficients(unsigned int dimension, unsigned int degree);
 
-  /** Iterator which only supports forward iteration and Begin(), IsAtEnd(), 
-   *  and Get() method which work just like as SimpleImageRegionIterator. */
+  /** \class SimpleForwardIterator
+   * \brief Iterator which only supports forward iteration and
+   * Begin(), IsAtEnd(), and Get() method which work just like as
+   * SimpleImageRegionIterator.
+   */
   class SimpleForwardIterator
-  {
-  public:
-    SimpleForwardIterator (MultivariateLegendrePolynomial* polynomial) 
     {
+    public:
+      SimpleForwardIterator (MultivariateLegendrePolynomial* polynomial) 
+      {
       m_MultivariateLegendrePolynomial = polynomial;
       m_Dimension   = m_MultivariateLegendrePolynomial->GetDimension();
       m_DomainSize  = m_MultivariateLegendrePolynomial->GetDomainSize();
       m_Index.resize(m_Dimension);
       std::fill(m_Index.begin(), m_Index.end(), 0);
-    }
+      }
     
     void Begin( void ) 
-    { 
+      { 
       m_IsAtEnd = false;
       for (unsigned int dim = 0; dim < m_Dimension; dim++)
-   {
-          m_Index[dim] = 0;
-   }
-    }
-    
+        {
+        m_Index[dim] = 0;
+        }
+      }
+      
     bool IsAtEnd()
-    { return m_IsAtEnd; }
+      { return m_IsAtEnd; }
     
     SimpleForwardIterator& operator++()
-    {
+      {
       for (unsigned int dim = 0; dim < m_Dimension; dim++)
         {
         if (m_Index[dim] < static_cast<int>(m_DomainSize[dim] - 1))
@@ -235,7 +240,7 @@ public:
           {
           if (dim == m_Dimension - 1 )
             {
-         m_IsAtEnd = true;
+            m_IsAtEnd = true;
             break;
             }
           else
@@ -245,10 +250,10 @@ public:
           }
         }
       return *this;
-    }
-    
+      }
+      
     double Get()
-    { return m_MultivariateLegendrePolynomial->Evaluate(m_Index); }
+      { return m_MultivariateLegendrePolynomial->Evaluate(m_Index); }
     
   private:
     MultivariateLegendrePolynomial* m_MultivariateLegendrePolynomial;
@@ -256,13 +261,14 @@ public:
     DomainSizeType    m_DomainSize;
     IndexType         m_Index;
     bool              m_IsAtEnd;
-  }; // end of class Iterator 
+    }; // end of class Iterator 
   
   void Print(std::ostream& os);
 
 protected:
   void PrintSelf(std::ostream& os, Indent indent) const;
-  double LegendreSum(const double x, int n, const CoefficientArrayType& coef,
+  double LegendreSum(const double x, int n, 
+                     const CoefficientArrayType& coef,
                      int offset = 0); 
   void CalculateXCoef(double norm_y, const CoefficientArrayType& coef);
   void CalculateYCoef(double norm_z, const CoefficientArrayType& coef);
