@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSPSAOptimizer.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-03-29 19:37:01 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-05-26 23:45:04 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -47,8 +47,8 @@ SPSAOptimizer
   m_GradientMagnitude = 0.0;
   m_NumberOfPerturbations = 1;
   m_LearningRate = 0.0;
-  m_a = 1.0;
-  m_c = 1.0;
+  m_Sa = 1.0;
+  m_Sc = 1.0;
   m_A = m_MaximumNumberOfIterations / 10;
   m_Alpha = 0.602;
   m_Gamma = 0.101;
@@ -65,11 +65,16 @@ SPSAOptimizer
 {
   Superclass::PrintSelf( os, indent );
 
-  os << indent << "a: " << m_a << std::endl;
+  os << indent << "a: " << m_Sa << std::endl;
   os << indent << "A: " << m_A << std::endl;
   os << indent << "Alpha: " << m_Alpha << std::endl;
-  os << indent << "c: " << m_c << std::endl;
+  os << indent << "c: " << m_Sc << std::endl;
   os << indent << "Gamma: " << m_Gamma << std::endl;
+  os << indent << "Tolerance: " << m_Tolerance << std::endl;
+  os << indent << "GradientMagnitude: " << m_GradientMagnitude << std::endl;
+  os << indent << "StateOfConvergenceDecayRate: " << m_StateOfConvergenceDecayRate << std::endl;
+  os << indent << "Gradient: " << m_Gradient << std::endl;
+  os << indent << "StateOfConvergence: " << m_StateOfConvergence << std::endl;
 
   os << indent << "NumberOfPerturbations: " << m_NumberOfPerturbations << std::endl;
 
@@ -297,7 +302,7 @@ double SPSAOptimizer
 ::Compute_a( unsigned long k ) const
 {
   return static_cast<double>(
-    m_a / vcl_pow( m_A + k + 1, m_Alpha ) );
+    m_Sa / vcl_pow( m_A + k + 1, m_Alpha ) );
 
 } // end Compute_a
 
@@ -312,7 +317,7 @@ double SPSAOptimizer
 ::Compute_c( unsigned long k ) const
 {
   return static_cast<double>(
-    m_c / vcl_pow( k + 1, m_Gamma ) );
+    m_Sc / vcl_pow( k + 1, m_Gamma ) );
 
 } // end Compute_c
 
@@ -344,9 +349,11 @@ void SPSAOptimizer
   for ( unsigned int j = 0; j < spaceDimension; j++ )
     {
     /** Generate randomly -1 or 1. */
-    // m_Delta[ j ] = 2 * vnl_math_rnd( vnl_sample_uniform(0.0f,1.0f) ) - 1;
-
+#ifdef ITK_USE_PORTABLE_ROUND
+    m_Delta[ j ] = 2 * Math::Round( this->m_Generator->GetUniformVariate (0.0f, 1.0f) ) - 1;
+#else
     m_Delta[ j ] = 2 * vnl_math_rnd ( this->m_Generator->GetUniformVariate (0.0f, 1.0f) ) - 1;
+#endif
 
     /**
      * Take scales into account. The perturbation of a parameter that has a
@@ -505,7 +512,7 @@ GuessParameters(
   averageAbsoluteGradient /= static_cast<double>(numberOfGradientEstimates);
 
   /** Set a in order to make the first steps approximately have an initialStepSize */
-  this->Seta( initialStepSize * vcl_pow(m_A + 1.0, m_Alpha) /
+  this->SetSa( initialStepSize * vcl_pow(m_A + 1.0, m_Alpha) /
               averageAbsoluteGradient.max_value() );
 
 } //end GuessParameters
