@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSingleValuedVnlCostFunctionAdaptor.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-12-31 18:35:16 $
-  Version:   $Revision: 1.21 $
+  Date:      $Date: 2008-04-30 23:25:18 $
+  Version:   $Revision: 1.22 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -188,6 +188,11 @@ SingleValuedVnlCostFunctionAdaptor
       {
       output[i] = -input[i];
       }
+
+    if(m_ScalesInitialized)
+      {
+      output[i] /= m_Scales[i];
+      }
     }
 }
 
