@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkLineSpatialObject.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:38 $
-  Version:   $Revision: 1.23 $
+  Date:      $Date: 2009-04-07 14:34:04 $
+  Version:   $Revision: 1.25 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -27,16 +27,16 @@ namespace itk
 {
 
 /** 
-* \class LineSpatialObject
-* \brief Representation of a Line based on the spatial object classes.
-*
-* The Line is basically defined by a set of points. 
-*
-* \sa LineSpatialObjectPoint 
-*/
+ * \class LineSpatialObject
+ * \brief Representation of a Line based on the spatial object classes.
+ *
+ * The Line is basically defined by a set of points. 
+ *
+ * \sa LineSpatialObjectPoint 
+ */
 
 template < unsigned int TDimension = 3 >
-class LineSpatialObject 
+class ITK_EXPORT LineSpatialObject 
   :public PointBasedSpatialObject<  TDimension >
 {
 
@@ -62,7 +62,7 @@ public:
   /** Method for creation through the object factory. */
   itkTypeMacro( LineSpatialObject, PointBasedSpatialObject );
   
-  /** Returns a reference to the list of the Line points.*/
+  /** Returns a reference to the list of the Line points. */
   PointListType & GetPoints( void );
 
   /** Set the list of line points. */
@@ -101,8 +101,7 @@ public:
    *  check the name of the class and the current depth */ 
   virtual bool IsInside( const PointType & point) const;
 
-
-  /** Compute the boundaries of the line.*/
+  /** Compute the boundaries of the line. */
   bool ComputeLocalBoundingBox() const;
 
 protected:
