@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSceneSpatialObject.h,v $
   Language:  C++
-  Date:      $Date: 2007-01-28 19:24:56 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-04-07 14:34:16 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,16 +26,16 @@ namespace itk
 { 
 
 /** \class SceneSpatialObject
-* \brief a SceneSpatialObject has a list of SpatialObjects
-*
-* This class represent a SceneSpatialObject object into which one can
-* plug any kind of spatial object.
-*
-* \sa SpatialObject
-*/ 
+ * \brief a SceneSpatialObject has a list of SpatialObjects
+ *
+ * This class represent a SceneSpatialObject object into which one can
+ * plug any kind of spatial object.
+ *
+ * \sa SpatialObject
+ */ 
  
 template <unsigned int TSpaceDimension = 3>
-class SceneSpatialObject 
+class ITK_EXPORT SceneSpatialObject 
   : public Object
 { 
  
@@ -76,11 +76,12 @@ public:
                                char * name=NULL );
 
   /** Returns the number of children currently assigned to 
-   *  the SceneSpatialObject object.*/ 
+   *  the SceneSpatialObject object. */ 
   unsigned int GetNumberOfObjects( unsigned int depth=MaximumDepth,
                                    char * name=NULL ); 
 
-  /** Set the list of pointers to children to the list passed as argument.*/ 
+  /** Set the list of pointers to children to the list passed as
+* argument. */ 
   void SetObjects( ObjectListType & children ); 
 
   /** Returns the latest modified time of all the objects contained 
