@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkSpatialObjectPoint.h,v $
   Language:  C++
-  Date:      $Date: 2004-10-05 15:40:49 $
-  Version:   $Revision: 1.14 $
+  Date:      $Date: 2009-04-07 14:34:17 $
+  Version:   $Revision: 1.16 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -26,14 +26,15 @@ namespace itk
 {
 
 /** \class SpatialObjectPoint
-* \brief Point used for spatial objets
-*
-* This class contains all the functions necessary to define a point
-*
-* \sa TubeSpatialObjectPoint SurfaceSpatialObjectPoint
-*/ 
+ * \brief Point used for spatial objets
+ *
+ * This class contains all the functions necessary to define a point
+ *
+ * \sa TubeSpatialObjectPoint SurfaceSpatialObjectPoint
+ */ 
+
 template < unsigned int TPointDimension = 3 >
-class SpatialObjectPoint 
+class ITK_EXPORT SpatialObjectPoint 
 {
 
 public:
@@ -54,10 +55,10 @@ public:
   /** Get the SpatialObjectPoint Id. */
   int GetID( void ) const;
 
-  /** Set the SpatialObjectPoint Id.*/
+  /** Set the SpatialObjectPoint Id. */
   void SetID(const int newID);
 
-  /** Return a pointer to the point object.*/
+  /** Return a pointer to the point object. */
   const PointType & GetPosition( void ) const;
 
   /** Set the point object. Couldn't use macros for these methods. */
