@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ResampleImageFilter9.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-02-26 03:23:28 $
-  Version:   $Revision: 1.9 $
+  Date:      $Date: 2009-02-20 19:23:32 $
+  Version:   $Revision: 1.10 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -127,6 +127,14 @@ int main( int argc, char * argv[] )
   // Software Guide : EndCodeSnippet
 
 
+  // Software Guide : BeginCodeSnippet
+  ImageType::DirectionType direction;
+  direction.SetIdentity();
+  nearestFilter->SetOutputDirection( direction );
+  linearFilter->SetOutputDirection( direction );
+  // Software Guide : EndCodeSnippet
+
+
   ImageType::SizeType   size;
 
   size[0] = 300;  // number of pixels along X
