@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: DeformableRegistration5.cxx,v $
   Language:  C++
-  Date:      $Date: 2005/11/19 16:31:50 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2007-09-07 14:17:42 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -97,7 +97,7 @@ int main( int argc, char *argv[] )
     std::cerr << " fixedImageFile movingImageFile ";
     std::cerr << " outputImageFile " << std::endl;
     std::cerr << " [outputDeformationFieldFile] " << std::endl;
-    return 1;
+    return EXIT_FAILURE;
     }
 
   // Software Guide : BeginLatex
@@ -514,7 +514,7 @@ int main( int argc, char *argv[] )
   catch( itk::ExceptionObject & excp )
     {
     std::cerr << excp << std::endl;
-    return -1;
+    return EXIT_FAILURE;
     }
 
 
@@ -522,6 +522,6 @@ int main( int argc, char *argv[] )
 
 
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 
