@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageRegistration17.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-11-22 00:30:16 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-05-05 17:32:20 $
+  Version:   $Revision: 1.7 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -142,6 +142,10 @@ int main( int argc, char *argv[] )
 
   HistogramSizeType  histogramSize;
 
+#ifdef ITK_USE_REVIEW_STATISTICS
+  histogramSize.SetSize(2);
+#endif
+  
   histogramSize[0] = 256;
   histogramSize[1] = 256;
 
@@ -300,6 +304,7 @@ int main( int argc, char *argv[] )
   TransformType::Pointer finalTransform = TransformType::New();
 
   finalTransform->SetParameters( finalParameters );
+  finalTransform->SetFixedParameters( transform->GetFixedParameters() );
 
   ResampleFilterType::Pointer resample = ResampleFilterType::New();
 
