@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ImageRegistrationHistogramPlotter.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-10-30 19:57:36 $
-  Version:   $Revision: 1.19 $
+  Date:      $Date: 2009-04-07 13:28:36 $
+  Version:   $Revision: 1.21 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -161,13 +161,13 @@ public:
     {
     if( (A > 0.0) )
       {
-      if( -(30.0 * log(A)) > 255 )
+      if( -(30.0 * vcl_log(A)) > 255 )
         {
         return static_cast<OutputPixelType>( 255 );
         }
       else
         {
-        return static_cast<OutputPixelType>( -(30.0 * log(A)) );
+        return static_cast<OutputPixelType>( -(30.0 * vcl_log(A)) );
         }
       }
     else 
@@ -679,6 +679,7 @@ int main( int argc, char *argv[] )
   TransformType::Pointer finalTransform = TransformType::New();
 
   finalTransform->SetParameters( finalParameters );
+  finalTransform->SetFixedParameters( transform->GetFixedParameters() );
 
   ResampleFilterType::Pointer resample = ResampleFilterType::New();
 
