@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: ModelToImageRegistration1.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-09-07 14:17:42 $
-  Version:   $Revision: 1.41 $
+  Date:      $Date: 2009-04-01 17:26:55 $
+  Version:   $Revision: 1.42 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -67,11 +67,11 @@
 //  Software Guide : EndLatex 
 
 //  Software Guide : BeginCodeSnippet
-#include <itkSpatialObjectToImageFilter.h>
+#include "itkSpatialObjectToImageFilter.h"
 //  Software Guide : EndCodeSnippet 
 
 
-#include <itkImageToSpatialObjectRegistrationMethod.h>
+#include "itkImageToSpatialObjectRegistrationMethod.h"
 
 
 //  Software Guide : BeginLatex
@@ -86,7 +86,7 @@
 //  Software Guide : EndLatex 
 
 //  Software Guide : BeginCodeSnippet
-#include <itkImageToSpatialObjectMetric.h>
+#include "itkImageToSpatialObjectMetric.h"
 //  Software Guide : EndCodeSnippet 
 
 
