@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkCorrelationCoefficientHistogramImageToImageMetricTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:02 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-05-05 17:51:19 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -89,6 +89,9 @@ int itkCorrelationCoefficientHistogramImageToImageMetricTest(int, char* [])
     
     unsigned int nBins = 256;
     MetricType::HistogramType::SizeType histSize;
+#ifdef ITK_USE_REVIEW_STATISTICS
+    histSize.SetSize(2);
+#endif
     histSize[0] = nBins;
     histSize[1] = nBins;
     metric->SetHistogramSize(histSize);
