@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMeanSquaresHistogramImageToImageMetricTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-12-27 21:28:05 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-05-05 18:16:17 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -89,6 +89,9 @@ int itkMeanSquaresHistogramImageToImageMetricTest(int , char* [])
     
     unsigned int nBins = 256;
     MetricType::HistogramType::SizeType histSize;
+#ifdef ITK_USE_REVIEW_STATISTICS
+    histSize.SetSize(2);
+#endif
     histSize[0] = nBins;
     histSize[1] = nBins;
     metric->SetHistogramSize(histSize);
