@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMultiResolutionPDEDeformableRegistrationTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2004-02-27 01:05:14 $
-  Version:   $Revision: 1.24 $
+  Date:      $Date: 2008-12-15 17:18:14 $
+  Version:   $Revision: 1.25 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -140,7 +140,7 @@ TImage *output )
 
 }
 
-int itkMultiResolutionPDEDeformableRegistrationTest(int, char* [] )
+int itkMultiResolutionPDEDeformableRegistrationTest(int argc, char* argv[] )
 {
 
   typedef unsigned char PixelType;
@@ -153,6 +153,12 @@ int itkMultiResolutionPDEDeformableRegistrationTest(int, char* [] )
   typedef ImageType::SizeType   SizeType;
   typedef ImageType::RegionType RegionType;
 
+  if(argc < 2)
+    {
+    std::cerr << "Usage: " << argv[0] << " WarpedImage\n";
+    return -1;
+    }
+
   //--------------------------------------------------------
   std::cout << "Generate input images and initial field";
   std::cout << std::endl;
@@ -293,27 +299,12 @@ int itkMultiResolutionPDEDeformableRegistrationTest(int, char* [] )
 
   warper->Update();
 
- //-------------------------------------------------------
-
-// uncomment to write out images
-/*
-  std::cout << "Write images to file " << std::endl;
   typedef itk::ImageFileWriter<ImageType> WriterType;
   WriterType::Pointer writer = WriterType::New();
-  
-  writer->SetInput( moving );
-  writer->SetFileName( "moving.png" );
-  writer->Write();
-
-  writer->SetInput( fixed );
-  writer->SetFileName( "fixed.png" );
-  writer->Write();
-
   writer->SetInput( warper->GetOutput() );
-  writer->SetFileName( "warp.png" );
-  writer->Write();
-*/
- 
+  writer->SetFileName( argv[1] );
+  writer->Update();
+  
   // ---------------------------------------------------------
   std::cout << "Compare warped moving and fixed." << std::endl;
 
@@ -338,15 +329,6 @@ int itkMultiResolutionPDEDeformableRegistrationTest(int, char* [] )
   std::cout << "Number of pixels different: " << numPixelsDifferent; 
   std::cout << std::endl;
 
-
-  if( numPixelsDifferent > 20 )
-    {
-    std::cout << "Test failed - too many pixels different." << std::endl;
-    return EXIT_FAILURE;
-    }
-
-
-
   //-------------------------------------------------------------
   std::cout << "Test when last shrink factors are not ones." << std::endl;
 
