@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNormalizedMutualInformationHistogramImageToImageMetricTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-12-10 23:17:16 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2009-05-05 19:27:44 $
+  Version:   $Revision: 1.6 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -90,6 +90,9 @@ int itkNormalizedMutualInformationHistogramImageToImageMetricTest(int,
     
     unsigned int nBins = 256;
     MetricType::HistogramType::SizeType histSize;
+#ifdef ITK_USE_REVIEW_STATISTICS
+    histSize.SetSize(2);
+#endif
     histSize[0] = nBins;
     histSize[1] = nBins;
     metric->SetHistogramSize(histSize);
