@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRegionGrow2DTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-06-10 13:02:48 $
-  Version:   $Revision: 1.41 $
+  Date:      $Date: 2009-04-06 17:39:26 $
+  Version:   $Revision: 1.42 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -1304,13 +1304,13 @@ unsigned int test_regiongrowKLM2D()
       return EXIT_FAILURE;
       }
 
-    labelEntropy -= probability * log( probability );
+    labelEntropy -= probability * vcl_log( probability );
 
     ++histIt;
     }
 
-  labelEntropy /= log( 2.0 );
-  double idealEntropy = - log( 8.0 / numPixels ) / log( 2.0 );
+  labelEntropy /= vcl_log( 2.0 );
+  double idealEntropy = - vcl_log( 8.0 / numPixels ) / vcl_log( 2.0 );
 
   std::cout << "Label entropy = " << labelEntropy << " bits " << std::endl;
   std::cout << "Ideal entropy = " << idealEntropy << " bits " << std::endl;
@@ -1945,13 +1945,13 @@ unsigned int test_regiongrowKLM3D()
       return EXIT_FAILURE;
       }
 
-    labelEntropy -= probability * log( probability );
+    labelEntropy -= probability * vcl_log( probability );
 
     ++histIt;
     }
 
-  labelEntropy /= log( 2.0 );
-  double idealEntropy = - log( 8.0/ numPixels ) / log( 2.0 );
+  labelEntropy /= vcl_log( 2.0 );
+  double idealEntropy = - vcl_log( 8.0/ numPixels ) / vcl_log( 2.0 );
 
   std::cout << "Label entropy = " << labelEntropy << " bits " << std::endl;
   std::cout << "Ideal entropy = " << idealEntropy << " bits " << std::endl;
@@ -2365,13 +2365,13 @@ unsigned int test_regiongrowKLM4D()
       return EXIT_FAILURE;
       }
 
-    labelEntropy -= probability * log( probability );
+    labelEntropy -= probability * vcl_log( probability );
 
     ++histIt;
     }
 
-  labelEntropy /= log( 2.0 );
-  double idealEntropy = - log( 1.0 / KLMFilter->GetNumberOfRegions() ) / log( 2.0 );
+  labelEntropy /= vcl_log( 2.0 );
+  double idealEntropy = - vcl_log( 1.0 / KLMFilter->GetNumberOfRegions() ) / vcl_log( 2.0 );
   std::cout << "Label entropy = " << labelEntropy << " bits " << std::endl;
   std::cout << "Ideal entropy = " << idealEntropy << " bits " << std::endl;
 
