@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkUnsharpMaskLevelSetImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-08-20 12:47:12 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-04-06 00:19:18 $
+  Version:   $Revision: 1.8 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -35,9 +35,13 @@ float square(unsigned x, unsigned y)
     Y = vnl_math_abs(y - (float)HEIGHT/2.0);
     float dis;
     if (!((X > RADIUS)&&(Y > RADIUS)))
+      {
       dis = RADIUS - vnl_math_max(X, Y);
+      }
     else
-      dis = -sqrt((X - RADIUS)*(X - RADIUS) +  (Y - RADIUS)*(Y - RADIUS));
+      {
+      dis = -vcl_sqrt((X - RADIUS)*(X - RADIUS) +  (Y - RADIUS)*(Y - RADIUS));
+      }
     return(dis);
 }
 
