@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBasicFiltersPrintTest2.cxx,v $
   Language:  C++
-  Date:      $Date: 2006/05/14 12:20:33 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2007-08-10 14:34:01 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -462,5 +462,5 @@ int itkBasicFiltersPrintTest2(int , char* [])
   std::cout << "-------------ZeroCrossingImageFilter" << ZeroCrossingImageFilterObj;
 #endif
 
-  return 0;
+  return EXIT_SUCCESS;
 }
