@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBasicFiltersTests.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-09-16 15:49:14 $
-  Version:   $Revision: 1.121 $
+  Date:      $Date: 2009-05-08 22:33:59 $
+  Version:   $Revision: 1.123 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -69,6 +69,8 @@ void RegisterTests()
   REGISTER_TEST(itkComposeRGBImageFilterTest );
   REGISTER_TEST(itkConfidenceConnectedImageFilterTest  );
   REGISTER_TEST(itkConnectedComponentImageFilterTest );
+  REGISTER_TEST(itkConnectedComponentImageFilterTooManyObjectsTest );
+  REGISTER_TEST(itkConnectedComponentImageFilterTestRGB );
   REGISTER_TEST(itkConnectedThresholdImageFilterTest  );
   REGISTER_TEST(itkConstantPadImageTest );
   REGISTER_TEST(itkCosImageFilterAndAdaptorTest );
