@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBasicFiltersTests5.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-10-06 04:08:59 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-03-18 19:28:21 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -36,4 +36,7 @@ void RegisterTests()
   REGISTER_TEST(itkBinaryThresholdProjectionImageFilterTest);
   REGISTER_TEST(itkProjectionImageFilterTest);
   REGISTER_TEST(itkImageToVectorImageFilterTest);
+  REGISTER_TEST(itkSimplexMeshWithFloatCoordRepTest);
+  REGISTER_TEST(itkReleaseDataFilterTest);
+  REGISTER_TEST(itkWarpImageFilterTest2);
 }
