@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkBinaryMagnitudeImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2006-01-15 04:28:36 $
-  Version:   $Revision: 1.8 $
+  Date:      $Date: 2009-04-05 10:56:54 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -145,25 +145,21 @@ int itkBinaryMagnitudeImageFilterTest(int, char* [] )
   //  Print the content of the result image
   std::cout << " Result " << std::endl;
   while( !it4.IsAtEnd() ) 
-  {
-    std::cout << it4.Get() << std::endl;
-    if( fabs( it4.Get() - outputValue ) > epsilon )
     {
+    std::cout << it4.Get() << std::endl;
+    if( vcl_fabs( it4.Get() - outputValue ) > epsilon )
+      {
       std::cerr << "Error in the output" << std::endl;
       std::cerr << "Value should be  " << outputValue << std::endl;
       std::cerr << "but is           " << it4.Get()  << std::endl;
       return EXIT_FAILURE;
-    }
+      }
 
     ++it4;
-  }
+    }
 
 
   // All objects should be automatically destroyed at this point
   return EXIT_SUCCESS;
 
 }
-
-
-
-
