@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkStatisticsImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-02-27 19:40:03 $
-  Version:   $Revision: 1.11 $
+  Date:      $Date: 2009-04-06 00:19:18 $
+  Version:   $Revision: 1.12 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -103,7 +103,7 @@ int itkStatisticsImageFilterTest(int, char* [] )
   filter->SetInput(source->GetOutput());
   filter->UpdateLargestPossibleRegion();
   
-  double expectedSigma = sqrt((maxValue-minValue)*(maxValue-minValue)/12.0);
+  double expectedSigma = vcl_sqrt((maxValue-minValue)*(maxValue-minValue)/12.0);
   double epsilon = (maxValue - minValue) * .001;
 
   if (vnl_math_abs(filter->GetSigma() - expectedSigma) > epsilon)
