@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkStreamingImageFilterTest2.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:08 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-02-04 16:37:58 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,9 +25,13 @@
 #include "itkStreamingImageFilter.h"
 #include "itkImageRegionMultidimensionalSplitter.h"
 #include "itkXMLFileOutputWindow.h"
+#include "../IO/itkPipelineMonitorImageFilter.h"
+
 
 int itkStreamingImageFilterTest2(int, char* [] )
 {
+  
+  const unsigned int numberOfStreamDivisions = 25;
   itk::XMLFileOutputWindow::Pointer logger = itk::XMLFileOutputWindow::New();
   logger->SetInstance(logger);
   
@@ -39,7 +43,7 @@ int itkStreamingImageFilterTest2(int, char* [] )
 
   // fill in an image
   ShortImage::IndexType  index = {{0, 0}};
-  ShortImage::SizeType   size = {{42, 63}};
+  ShortImage::SizeType   size = {{42, 64}};
   ShortImage::RegionType region;
   region.SetSize( size );
   region.SetIndex( index );
@@ -69,11 +73,16 @@ int itkStreamingImageFilterTest2(int, char* [] )
   itk::ImageRegionMultidimensionalSplitter<2>::Pointer splitter;
   splitter = itk::ImageRegionMultidimensionalSplitter<2>::New();
   splitter->DebugOn();
-  
+    
+  // monitor what's going on
+  itk::PipelineMonitorImageFilter<ShortImage>::Pointer monitor;
+  monitor = itk::PipelineMonitorImageFilter<ShortImage>::New();
+  monitor->SetInput( shrink->GetOutput() );
+
   itk::StreamingImageFilter<ShortImage, ShortImage>::Pointer streamer;
   streamer = itk::StreamingImageFilter<ShortImage, ShortImage>::New();
-  streamer->SetInput( shrink->GetOutput() );
-  streamer->SetNumberOfStreamDivisions( 25 );
+  streamer->SetInput( monitor->GetOutput() );
+  streamer->SetNumberOfStreamDivisions( numberOfStreamDivisions );
   streamer->SetRegionSplitter( splitter );
   streamer->Update();
 
@@ -83,6 +92,16 @@ int itkStreamingImageFilterTest2(int, char* [] )
             << ", "
             << streamer->GetOutput()->GetSpacing()[1] << std::endl;
 
+  
+  // check if the pipeline executed as expected
+  if (monitor->GetNumberOfUpdates() != numberOfStreamDivisions ||
+      monitor->GetOutputRequestedRegions().size() != numberOfStreamDivisions) 
+    {    
+    std::cout << monitor;
+    std::cout << "ImageStreaming Filter test failed because pipeline didn't execute as expected." << std::endl;
+    return EXIT_FAILURE;
+    }
+
 
   //
   // The rest of this code determines whether the shrink code produced
@@ -94,17 +113,46 @@ int itkStreamingImageFilterTest2(int, char* [] )
   itk::ImageRegionIterator<ShortImage>
     iterator2(streamer->GetOutput(), requestedRegion);
 
+  // If size is not a multiple of the shrink factors, then adjust the
+  // row/col indicies
+  short rowOffset = 0;
+  short colOffset = 0;
+  if (region.GetSize()[1] % shrink->GetShrinkFactors()[1])
+    {
+    rowOffset = static_cast<short>(
+      region.GetSize()[1] / 2.0 -
+      ((region.GetSize()[1] / shrink->GetShrinkFactors()[1]) / 2.0 *
+       shrink->GetShrinkFactors()[1])
+      );
+    }
+  if (region.GetSize()[0] % shrink->GetShrinkFactors()[0])
+    {
+    colOffset = static_cast<short>(
+      region.GetSize()[0] / 2.0 -
+      ((region.GetSize()[0] / shrink->GetShrinkFactors()[0]) / 2.0 *
+       shrink->GetShrinkFactors()[0])
+      );
+    }
+
   bool passed = true;
   for (; !iterator2.IsAtEnd(); ++iterator2)
     {
-    short trueValue = (short) (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0])
-              + (region.GetSize()[0]
-                * shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1]);
+    short col = (shrink->GetShrinkFactors()[0] * iterator2.GetIndex()[0] +
+                 (shrink->GetShrinkFactors()[0] - 1) / 2);
+    col += colOffset;
+
+    short row = (shrink->GetShrinkFactors()[1] * iterator2.GetIndex()[1] +
+                 (shrink->GetShrinkFactors()[1] - 1) / 2);
+    row += rowOffset;
+    short trueValue = col + region.GetSize()[0] * row;
 
     if ( iterator2.Get() != trueValue )
       {
       passed = false;
-      std::cout << "Pixel " << iterator2.GetIndex() << " is incorrect" << std::endl;
+      std::cout << "Pixel " << iterator2.GetIndex() 
+                << " expected " << trueValue
+                << " but got " << iterator2.Get()
+                << std::endl;
       }
     }
 
