@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkVectorExpandImageFilterTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-01-29 14:42:11 $
-  Version:   $Revision: 1.10 $
+  Date:      $Date: 2009-05-19 20:36:25 $
+  Version:   $Revision: 1.11 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -25,7 +25,12 @@
 #include "itkImage.h"
 #include "itkImageRegionIteratorWithIndex.h"
 #include "itkVectorExpandImageFilter.h"
-//#include "itkVectorCastImageFilter.h"
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
+#include "itkVectorLinearInterpolateImageFunction.h"
+#else
+#include "itkVectorNearestNeighborInterpolateImageFunction.h"
+#endif
+#include "itkVectorCastImageFilter.h"
 #include "itkStreamingImageFilter.h"
 #include "itkCommand.h"
 #include "vnl/vnl_math.h"
@@ -133,7 +138,11 @@ int itkVectorExpandImageFilterTest(int, char* [] )
 
   expander->SetInput( input );
 
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
   typedef itk::VectorLinearInterpolateImageFunction<ImageType,double> InterpolatorType;
+#else
+  typedef itk::VectorNearestNeighborInterpolateImageFunction<ImageType,double> InterpolatorType;
+#endif
   InterpolatorType::Pointer interpolator = InterpolatorType::New();
 
   expander->SetInterpolator( interpolator );
@@ -170,17 +179,22 @@ int itkVectorExpandImageFilterTest(int, char* [] )
   ImageType::RegionType validRegion = 
     expander->GetOutput()->GetLargestPossibleRegion();
   ImageType::SizeType validSize = validRegion.GetSize();
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
   for( j = 0; j < ImageDimension; j++ )
     {
     validSize[j] -= (factors[j] - 1);
     }
+#endif
+
   validRegion.SetSize( validSize );
 
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
   // adjust the pattern coefficients to match
   for( j = 0; j < ImageDimension; j++ )
     {
     pattern.coeff[j] /= (double) factors[j];
     }
+#endif
 
   for( ; !outIter.IsAtEnd(); ++outIter )
     {
@@ -190,7 +204,15 @@ int itkVectorExpandImageFilterTest(int, char* [] )
     if( validRegion.IsInside( index ) )
       {
 
+#ifndef ITK_USE_CENTERED_PIXEL_COORDINATES_CONSISTENTLY
       double baseValue = pattern.Evaluate( outIter.GetIndex() );
+#else
+      ImageType::PointType point;
+      ImageType::IndexType inputIndex;
+      expander->GetOutput()->TransformIndexToPhysicalPoint( outIter.GetIndex(), point );
+      input->TransformPhysicalPointToIndex(point, inputIndex );
+      double baseValue = pattern.Evaluate( inputIndex );
+#endif
 
       for( k = 0; k < VectorDimension; k++ )
         {
@@ -227,19 +249,17 @@ int itkVectorExpandImageFilterTest(int, char* [] )
   std::cout << "Run ExpandImageFilter with streamer";
   std::cout << std::endl;
 
-/*
   typedef itk::VectorCastImageFilter<ImageType,ImageType> CasterType;
   CasterType::Pointer caster = CasterType::New();
 
   caster->SetInput( expander->GetInput() );
-*/
 
   ExpanderType::Pointer expander2 = ExpanderType::New();
 
-//  expander2->SetInput( caster->GetOutput() );
-  expander2->SetInput( expander->GetInput() );
+  expander2->SetInput( caster->GetOutput() );
   expander2->SetExpandFactors( expander->GetExpandFactors() );
   expander2->SetEdgePaddingValue( expander->GetEdgePaddingValue() );
+  expander2->SetInterpolator( expander->GetInterpolator() );
 
   typedef itk::StreamingImageFilter<ImageType,ImageType> StreamerType;
   StreamerType::Pointer streamer = StreamerType::New();
