@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkMedialNodeCorrespondencesTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-12-15 14:13:21 $
-  Version:   $Revision: 1.7 $
+  Date:      $Date: 2009-05-07 14:04:07 $
+  Version:   $Revision: 1.9 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -180,9 +180,13 @@ int itkMedialNodeCorrespondencesTest(int, char *[])
     // Set filter parameters
     binfilter->SetInput(sourceImage);
     if(i == 0)
+      {
       binfilter->SetRepetitions(4);
+      }
     else
+      {
       binfilter->SetRepetitions(3);
+      }
 
     // Set up the output of the filter
     ImageType::Pointer blurredImage = binfilter->GetOutput();
@@ -216,10 +220,15 @@ int itkMedialNodeCorrespondencesTest(int, char *[])
     caFilter->SetInput(bloxBoundaryPointImage);
     caFilter->SetDistanceMin(8.0);
     caFilter->SetDistanceMax(12.0);
+
     if(i == 0)
+      {
       caFilter->SetEpsilon(0.05);
+      }
     else
+      {
       caFilter->SetEpsilon(0.05);
+      }
 
     caFilter->SetPolarity(0);
 
@@ -244,9 +253,13 @@ int itkMedialNodeCorrespondencesTest(int, char *[])
     bloxCoreAtomImage->DoCoreAtomVoting();
 
     if(i == 0)
-      {bloxCoreAtomImage1 = bloxCoreAtomImage;}
+      {
+      bloxCoreAtomImage1 = bloxCoreAtomImage;
+      }
     else
-      {bloxCoreAtomImage2 = bloxCoreAtomImage;}
+      {
+      bloxCoreAtomImage2 = bloxCoreAtomImage;
+      }
     }
 
   int numberNodes1 = bloxCoreAtomImage1->GetMedialNodeCount();
@@ -345,11 +358,11 @@ int itkMedialNodeCorrespondencesTest(int, char *[])
     {
     for(int j=0;j<numberNodes1;++j)
       {
-      if( fabs(distanceMatrix->get(i,j) - correctDistance->get(i,j)) >= 0.0001) 
+      if( vcl_fabs(distanceMatrix->get(i,j) - correctDistance->get(i,j)) >= 0.0001) 
         {
         indexI = i;
         indexJ = j;
-        difference = fabs(distanceMatrix->get(i,j) - correctDistance->get(i,j));
+        difference = vcl_fabs(distanceMatrix->get(i,j) - correctDistance->get(i,j));
         distanceSuccess = false;
         break;
         }
@@ -466,11 +479,11 @@ int itkMedialNodeCorrespondencesTest(int, char *[])
     {
     for(int l = 0; l < numberNodes2; l++)
       {
-      if( fabs(correspondenceMatrix->get(k,l) - correctCorrespondenceMatrix->get(k,l)) >= 0.0001)
+      if( vcl_fabs(correspondenceMatrix->get(k,l) - correctCorrespondenceMatrix->get(k,l)) >= 0.0001)
         {
         indexK = k;
         indexL = l;
-        difference2 = fabs(correspondenceMatrix->get(k,l) - correctCorrespondenceMatrix->get(k,l));
+        difference2 = vcl_fabs(correspondenceMatrix->get(k,l) - correctCorrespondenceMatrix->get(k,l));
         unarySuccess = false;
         break;
         }
