@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkNearestNeighborExtrapolateImageFunctionTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:09 $
-  Version:   $Revision: 1.3 $
+  Date:      $Date: 2009-05-26 23:45:06 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -70,8 +70,13 @@ int itkNearestNeighborExtrapolateImageFunctionTest( int, char *[])
   point[1] = 3.25;
   value = function->Evaluate( point );
 
+#ifdef ITK_USE_PORTABLE_ROUND
+  trueValue = itk::Math::Round( point[0] ) +
+    ( itk::Math::Round( point[1] ) )  * static_cast<double>( imageSize[0] );
+#else
   trueValue = vnl_math_rnd( point[0] ) +
     ( vnl_math_rnd( point[1] ) )  * static_cast<double>( imageSize[0] );
+#endif
 
   std::cout << "Point: " << point << " Value: " << value << std::endl;
   if ( value != trueValue )
@@ -86,8 +91,13 @@ int itkNearestNeighborExtrapolateImageFunctionTest( int, char *[])
   point[1] = 8.0;
   value = function->Evaluate( point );
 
+#ifdef ITK_USE_PORTABLE_ROUND
+  trueValue = itk::Math::Round( point[0] ) +
+    ( 6.0 )  * static_cast<double>( imageSize[0] );
+#else
   trueValue = vnl_math_rnd( point[0] ) +
     ( 6.0 )  * static_cast<double>( imageSize[0] );
+#endif
 
   std::cout << "Point: " << point << " Value: " << value << std::endl;
   if ( value != trueValue )
