@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkPointGeometryTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2008-01-18 18:53:14 $
-  Version:   $Revision: 1.20 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.21 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -143,7 +143,7 @@ int itkPointGeometryTest(int, char* [] )
     {
     FloatPointType::ValueType val = 
         static_cast< FloatPointType::ValueType >( dp[i] );
-    if( fabs ( val - fp[i] ) > tolerance )
+    if( vcl_fabs ( val - fp[i] ) > tolerance )
       {
         std::cout << "Failed at component " << i << std::endl;
         return EXIT_FAILURE;
@@ -197,7 +197,7 @@ int itkPointGeometryTest(int, char* [] )
     for(unsigned int i=0; i<N; i++ )
     {
       const double value = (alpha*A[i]+(1.0-alpha)*B[i]);
-      if( fabs(combination[i] - value ) > tolerance )
+      if( vcl_fabs(combination[i] - value ) > tolerance )
       {
         std::cerr << "Failure to compute Barycentric combination" << std::endl;
         return EXIT_FAILURE;
@@ -231,7 +231,7 @@ int itkPointGeometryTest(int, char* [] )
     for(unsigned int i=0; i<N; i++ )
     {
       const double value = alpha*A[i]+beta*B[i]+(1.0-alpha-beta)*C[i];
-      if( fabs( combination[i] - value ) > tolerance )
+      if( vcl_fabs( combination[i] - value ) > tolerance )
       {
         std::cerr << "Failure to compute Barycentric combination" << std::endl;
         return EXIT_FAILURE;
@@ -260,7 +260,7 @@ int itkPointGeometryTest(int, char* [] )
     std::cout << "Test for Barycentric combination of an array of Points" << std::endl;
     for(unsigned int i=0; i<N; i++ )
     {
-      if( fabs( combination[i] - (K/3.0) ) > tolerance )
+      if( vcl_fabs( combination[i] - (K/3.0) ) > tolerance )
       {
         std::cerr << "Failure to compute Barycentric combination" << std::endl;
         return EXIT_FAILURE;
@@ -300,7 +300,7 @@ int itkPointGeometryTest(int, char* [] )
     std::cout << "Test for Barycentric combination of a VectorContainer of Points" << std::endl;
     for(unsigned int i=0; i<N; i++ )
     {
-      if( fabs( combination[i] - (K/3.0) ) > tolerance )
+      if( vcl_fabs( combination[i] - (K/3.0) ) > tolerance )
       {
         std::cerr << "Failure to compute Barycentric combination" << std::endl;
         return EXIT_FAILURE;
