@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkRigid3DPerspectiveTransformTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2003-09-10 14:30:10 $
-  Version:   $Revision: 1.12 $
+  Date:      $Date: 2009-04-05 10:56:56 $
+  Version:   $Revision: 1.13 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -50,7 +50,7 @@ int itkRigid3DPerspectiveTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( fabs( offset[i]-0.0 ) > epsilon )
+      if( vcl_fabs( offset[i]-0.0 ) > epsilon )
       {
         Ok = false;
         break;    
@@ -81,7 +81,7 @@ int itkRigid3DPerspectiveTransformTest(int ,char * [] )
 
     for(unsigned int i=0; i<N; i++)
     {
-      if( fabs( offset[i]- ioffset[i] ) > epsilon )
+      if( vcl_fabs( offset[i]- ioffset[i] ) > epsilon )
       {
         Ok = false;
         break;    
@@ -107,7 +107,7 @@ int itkRigid3DPerspectiveTransformTest(int ,char * [] )
       r = translation->TransformPoint( p );
       for(unsigned int i=0; i<N-1; i++)
       {
-        if( fabs( s[i]- r[i] ) > epsilon )
+        if( vcl_fabs( s[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
@@ -144,7 +144,7 @@ int itkRigid3DPerspectiveTransformTest(int ,char * [] )
     typedef TransformType::VersorType  VersorType;
     VersorType rotation;
     VersorType::VectorType axis;
-    VersorType::ValueType  angle = 30.0f * atan( 1.0f ) / 45.0f;
+    VersorType::ValueType  angle = 30.0f * vcl_atan( 1.0f ) / 45.0f;
     axis[0] = 1.0f;
     axis[1] = 1.0f;
     axis[2] = 1.0f;
@@ -166,7 +166,7 @@ int itkRigid3DPerspectiveTransformTest(int ,char * [] )
       r = rigid->TransformPoint( p );
       for(unsigned int i=0; i<N-1; i++)
       {
-        if( fabs( s[i]- r[i] ) > epsilon )
+        if( vcl_fabs( s[i]- r[i] ) > epsilon )
         {
           Ok = false;
           break;    
