@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkStimulateImageIOTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-02-24 17:03:22 $
-  Version:   $Revision: 1.4 $
+  Date:      $Date: 2009-03-22 21:13:02 $
+  Version:   $Revision: 1.5 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -66,17 +66,24 @@ int itkStimulateImageIOTest(int argc, char* argv[] )
     return EXIT_FAILURE;
     }
 
-  // Create a source object (in this case a reader)
-  itk::ImageFileReader<FloatImageType>::Pointer reader;
-  reader = itk::ImageFileReader<FloatImageType>::New();
-  reader->SetImageIO(sprIO);
-  reader->SetFileName(argv[1]);
-  reader->Update();
-
-  writer->SetInput(reader->GetOutput());
-  writer->SetFileName(argv[2]);
-  writer->Write();
+  try
+    {
+    // Create a source object (in this case a reader)
+    itk::ImageFileReader<FloatImageType>::Pointer reader;
+    reader = itk::ImageFileReader<FloatImageType>::New();
+    reader->SetImageIO(sprIO);
+    reader->SetFileName(argv[1]);
+    reader->Update();
 
+    writer->SetInput(reader->GetOutput());
+    writer->SetFileName(argv[2]);
+    writer->Write();
+    }
+  catch (itk::ExceptionObject &e)
+    {
+    std::cerr << e << std::endl;
+    return EXIT_FAILURE;
+    }
   return EXIT_SUCCESS;
 }
 
