@@ -3,8 +3,8 @@
   Program:   Insight Segmentation & Registration Toolkit
   Module:    $RCSfile: itkAffineGeometryFrameTest.cxx,v $
   Language:  C++
-  Date:      $Date: 2005-03-24 01:12:55 $
-  Version:   $Revision: 1.2 $
+  Date:      $Date: 2009-04-07 14:34:45 $
+  Version:   $Revision: 1.3 $
 
   Copyright (c) Insight Software Consortium. All rights reserved.
   See ITKCopyright.txt or http://www.itk.org/HTML/Copyright.htm for details.
@@ -33,6 +33,8 @@ int itkAffineGeometryFrameTest(int, char* [])
   typedef itk::AffineGeometryFrame<> AffineGeometryFrameType;
 
   AffineGeometryFrameType::Pointer geometryFrame1 = AffineGeometryFrameType::New();
+  std::cout << "Testing Print before initialization" << std::endl;
+  geometryFrame1->Print(std::cout);
 
   std::cout << "Testing Initialize(): ";
   geometryFrame1->Initialize();
@@ -167,6 +169,9 @@ int itkAffineGeometryFrameTest(int, char* [])
     std::cerr << " [FAILED]" << std::endl;
     return EXIT_FAILURE;
     }
+  std::cout << "Testing Print after initialization" << std::endl;
+  geometryFrame1->Print(std::cout);
+
   std::cout<<"[PASSED]"<<std::endl;
 
   std::cout<<"[TEST DONE]"<<std::endl;
