@@ -3,8 +3,8 @@
   Program:   gdcm
   Module:    $RCSfile: gdcmArgMgr.cxx,v $
   Language:  C++
-  Date:      $Date: 2007-04-29 12:11:37 $
-  Version:   $Revision: 1.5 $
+  Date:      $Date: 2008-05-14 07:08:04 $
+  Version:   $Revision: 1.6 $
   
   Copyright (c) CREATIS (Centre de Recherche et d'Applications en Traitement de
   l'Image). All rights reserved. See Doc/License.txt or
@@ -793,7 +793,7 @@ const char *ArgMgr::LoadedParam ( const char *param, FILE *fd )
   int    nbcar = 0;
 
   /* remove spaces at the beginning****/
-  while ( isspace(carlu=fgetc (fd)) );
+  while ( isspace(carlu=fgetc (fd)) ) {}
   if (carlu==EOF)
      return 0;
   /* Search for a " */
