@@ -14,6 +14,7 @@
 //  Modifications
 //   Peter Vanroose, 25 June 1999: vnl_vector_fixed<double,2> already instantiated
 //   Peter Vanroose, 28 Mar. 2004: renamed cross_2d() to vnl_cross_2d()
+//   Peter Vanroose, 24 Mar. 2007: removed deprecated cross_2d() alias
 // \endverbatim
 
 #include <vnl/vnl_T_n.h>
@@ -28,7 +29,4 @@ double vnl_cross_2d(vnl_double_2 const& v1, vnl_double_2 const& v2)
   return v1[0] * v2[1] - v1[1] * v2[0];
 }
 
-//: deprecated
-#define cross_2d vnl_cross_2d
-
 #endif // vnl_double_2_h_
